<?php

return array(
    'attendanceIsMarked' => 'Attendance is marked for the date',
    'autoClockOut' => 'Enter no of hours from the end time after which employee will be auto clocked out. <br><br><b>Example:</b> If shift end time is 6 PM and auto clockout value is 1 then employee will be auto clocked out at 7 PM.<br><br><b>Note</b>: Auto clock out will not work if allow clock-in outside shift hours is checked in attendance settings.',
    'flexibleAutoClockOut' => 'Enter no of hours after which employee will be auto clocked out. <br><br><b>Example:</b> If total shift hours are 8 hours and auto clockout value is 1 then employee will be auto clocked out after 9 Hours.',
    'fetchChat' => 'Fetching chat detail.',
    'leaveQuotaShowing' => 'Showing leave quota records From :start_date To :end_date.',
    'moduleDisabled' => 'Module is disabled.',
    'taskTimerRunning' => 'Task timer is Active',
    'timerOkay' => 'Okay',
    'stopTheTimer' => 'Tasks with active timer cannot be removed.',
    'confirm' => 'Confirm',
    'exitDateErrorForPast' => 'If you try to activate, you need to remove the exit date; otherwise, the employee will become inactive the next day (:date). Because the exit date is older than today.',
    'exitDateErrorForFuture' => 'If you will try to active, you need to remove the exit date; otherwise, the employee will become inactive the next day (:date).',
    'approvalmsgsent' => 'This task requires approval from the project administrator before being marked as complete. Please send the task for approval to the project administrator.',
    'youCannotMoveTask' => 'You cannot move this task to the selected status.',
    'markAsPaid' => 'Invoice amount is zero, it will be marked as paid.',
    'projectCodeRequired' => 'Project short code field is required.',
    'changeLeaveStatusConfirmation' => 'Do you want to change leave status.',
    'fristSignAndQrCodeError' => 'Auto clock-in employee by first sign in and QR Code cannot be turned ON at the same time.',
    'qrCodeAndFirstSignError' => '\'QR Code\' and \'Auto clock-in employee by first sign in\' cannot be enabled simultaneously. To enable QR Code, please first disable \'Auto Clock-In by First Sign-In\'.',
    'updateSuccess' => 'Updated successfully.',
    'updateSuccessWithSomeSkipped' => 'Leaves which were already approved or rejected were not updated. The remaining leaves were updated successfully.',
    'noUpdateMade' => 'No leaves were updated because all selected leaves were either already approved or rejected.',
    'requestSent' => 'Request has been sent for approval',
    'requestSentOffline' => 'In offline pay method request will be sent for approval',
    'recordSaved' => 'Record saved successfully',
    'deleteSuccess' => 'Deleted successfully.',
    'checkDayHoliday' => 'Choose at-least 1.',
    'addItem' => 'Add at-least 1 item.',
    'quantityNumber' => 'Quantity should be a number',
    'unitPriceNumber' => 'Unit price should be a number',
    'amountNumber' => 'Amount should be a number.',
    'itemBlank' => 'Item name cannot be blank.',
    'invalidRequest' => 'Invalid Request',
    'fileUploadedSuccessfully' => 'File uploaded successfully.',
    'fileUploadIssue' => 'File is not uploaded. Please contact to administrator',
    'issueStatusChanged' => 'Issue status changed successfully.',
    'newTaskAddedToTheProject' => 'New task added to the project.',
    'timerStoppedSuccessfully' => 'Timer stopped successfully.',
    'attendanceSaveSuccess' => 'Attendance Saved Successfully.',
    'attendanceClockInSuccess' => 'Clock-in Successfully',
    'attendanceClockOutSuccess' => 'Clock-out Successfully',
    'leadClientChangeSuccess' => 'Lead changed in client successfully.',
    'adminCannotDelete' => 'Admin user cannot be deleted.',
    'roleCannotChange' => 'To change the role of this user, You need to assign the same role to some other user and then login as that user to change it',
    'roleAssigned' => 'Roles assigned successfully.',
    'leaveAssignSuccess' => 'Leave assigned successfully.',
    'leaveTypeAdded' => 'Leave type saved.',
    'reasonForLeaveRejection' => 'Reason for leave rejection',
    'reasonForLeaveApproval' => 'Reason for leave approval',
    'importSuccess' => 'File imported successfully.',
    'newFileUploadedToTheProject' => 'New file uploaded to the project.',
    'isAddedAsProjectMember' => 'is added as a project member.',
    'memberRemovedFromProject' => 'Member removed from project successfully.',
    'milestoneSuccess' => 'Milestone saved successfully.',
    'addedAsNewProject' => 'added as a new project.',
    'projectArchiveSuccessfully' => 'Project archived successfully.',
    'archiveSuccess' => 'Leave type archived successfully.',
    'restoreSuccess' => 'Leave type reverted successfully.',
    'projectRevertSuccessfully' => 'Project reverted successfully.',
    'noMemberAddedToProject' => 'No member added to this project.',
    'ticketReplySuccess' => 'Reply sent successfully.',
    'timeLogAdded' => 'Time logged successfully.',
    'timelogAlreadyExist' => 'Time-log already exists for this user.',
    'noConversation' => 'No conversation found.',
    'noUser' => 'No user found.',
    'agentRemoveSuccess' => 'Agent removed successfully.',
    'templateUpdateSuccess' => 'Template update success.',
    'notAnAuthorisedDevice' => 'This is not an authorized device for clock-in or clock-out',
    'notAnValidLocation' => 'Your current location is not with in the clock-in range',
    'qrDisabled' => 'QR Clock-in feature is disabled for this company.',
    'unAuthorisedUser' => 'You are not a authorised user.',
    'updatedProfile' => 'Updated profile.',
    'taskUpdated' => 'Marked the task as ',
    'timerStartedTask' => 'Started the timer for task ',
    'timerStartedSuccessfully' => 'Timer started successfully.',
    'timerAlreadyRunning' => 'Timer is already running for a task.',
    'notificationRead' => 'Notification marked as read.',
    'atleastOneValidation' => 'Select at least 1 member',
    'repeatCyclesValidation' => 'The repeat every field is required.',
    'cyclesValidation' => 'The cycles field is required.',
    'chooseProject' => 'Choose a project.',
    'noRecordFound' => 'No record found.',
    'currencyConvertApiKeyUrl' => 'Get API key by this url',
    'exchangeRateNote' => 'Exchange rate is calculated from your default currency. Change default currency in App Settings.',
    'earningChartNote' => 'The earnings are mentioned in your base currency.',
    'noPendingLeadFollowUps' => 'No pending follow-up.',
    'employeeDocsAllowedFormat' => 'Allowed file formats: jpg, png, gif, doc, docx, xls, xlsx, pdf, txt.',
    'noFileUploaded' => 'No file uploaded.',
    'noLeadSourceAdded' => 'No lead source added.',
    'noLeadStatusAdded' => 'No lead status added.',
    'noCustomField' => 'No Custom Field added.',
    'selectMultipleDates' => 'You can select multiple dates.',
    'sweetAlertTitle' => 'Are you sure?',
    'unArchiveMessage' => 'Do you want to restore this project.',
    'confirmRevert' => 'Yes, Restore it!',
    'confirmNoArchive' => 'No, cancel please!',
    'confirmNo' => 'No, please!',
    'archiveMessage' => 'Do you want to archive this project.',
    'confirmArchive' => 'Yes, archive it!',
    'noInvoice' => 'No invoice created.',
    'noClientAddedToProject' => 'No client assigned to the project.',
    'noAgentAdded' => 'No agent added.',
    'noPaymentAdded' => 'No payment added.',
    'noTemplateFound' => 'No template found.',
    'noTicketTypeAdded' => 'No ticket type added.',
    'paymentTypeNotFound' => 'Payment Type Not Found',
    'noSubTaskFound' => 'Seems like no sub task exists in the database. Please create the sub task first',
    'noActivityByThisUser' => 'No activity by the user.',
    'noClientAdded' => 'No client added.',
    'confirmDelete' => 'Yes, delete it!',
    'confirmRemove' => 'Yes, remove it!',
    'confirmSend' => 'Yes, send it!',
    'creditText' => 'When creating a credit note from non-paid invoice, full invoice amount will be credited. Are you sure that you want to create the credit note?',
    'confirmCreate' => 'Yes, create it!',
    'invoiceText' => 'Do you want to cancel the invoice?',
    'recoverRecord' => 'You will not be able to recover the deleted record!',
    'confirmPin' => 'Yes, pin it!',
    'confirmUnpin' => 'Yes, unpin it!',
    'projectPin' => 'You want to pin this project!',
    'removeAgentText' => 'This will remove the agent from the list.',
    'removeChannelText' => 'This will remove the channel type from the list.',
    'removeGroupText' => 'This will delete the group from the list.',
    'removeTemplateText' => 'This will remove the template from the list.',
    'removeTicketText' => 'This will remove the ticket type from the list.',
    'ticketText' => 'You will not be able to recover the deleted ticket!',
    'removeFileText' => 'You will not be able to recover the deleted file!',
    'markHolidayTitle' => 'Are you sure you want to mark selected days as holiday ?',
    'noteHolidayText' => 'Note: This will mark all the selected days throughout the year as holidays. You will have to manually delete them once added.',
    'confirmSave' => 'Yes, save it!',
    'deleteInvoice' => 'You will not be able to recover the deleted recurring invoice!',
    'removeLead' => 'This will remove the lead status from the list.',
    'deleteLeave' => 'You will not be able to recover the deleted leave!',
    'deleteLeaveType' => 'You will not be able to recover the deleted leave type!',
    'unArchiveMessageLeave' => 'Do you want to restore this leave type.',
    'archiveMessageLeave' => 'Do you want to archive this leave type.',
    'removeMethodText' => 'This will remove the payment method from the list',
    'deleteProduct' => 'You will not be able to recover the deleted product!',
    'deleteTask' => 'You will not be able to recover the deleted task!',
    'markCompleteTask' => 'There is an incomplete sub-task in this task do you want to mark complete!',
    'sendApprovalTask' => 'Do you want to send approval for this task to admin?',
    'approvalmsg' => 'You will not be able to make any changes to the task till the task is reviewed.',
    'sendReminder' => 'Do you want to send a reminder to the assigned employee?',
    'completeIt' => 'Yes, complete it!',
    'noCategoryAdded' => 'No category added',
    'incorrectPassword' => 'Incorrect Password',
    'passwordMatched' => 'Password Matched',
    'departmentName' => 'Department name is required',
    'departmentUniq' => 'The department name has already been taken.',
    'unitTypeAdded' => 'Unit Type Added Successfully',
    'estimateTemplateDeleted' => 'Estimate Template Deleted',
    'estimateTemplateCreated' => 'Estimate Template Created',
    'estimateTemplateUpdated' => 'Estimate Template Updated',
    'clientFinanceCount' => 'This client have :projectCount :project, :invoiceCount :invoice, :estimateCount :estimate, :paymentCount :payment . ',
    'signatureAdded' => 'Signature Added Successfully',
    'endTimeAfterOrEqual' => 'The end time must be a time after or equal to the start time.',
    'enterText' => 'Enter Text Here',
    'selectOfflineMethod' => 'Offline method is required if you select offline.',
    'invoicePaymentError' => 'Please enter amount.',
    'selectGateway' => 'Payment method required.',
    'invoiceDateError' => 'Please enter date.',
    'holidayError' => 'Holiday already applied for the selected date.',
    'invalidShiftDayError' => 'Shift is not available on',
    'cartEmpty' => 'Your cart is emplty successfully.',
    'emptyCartMessage' => 'Your cart is empty successfully.',
    'ticketCreateSuccess' => 'Ticket created successfully.',
    'pleaseEnterSomeData' => 'Please enter some data to save bulk payments.',
    'atleastOneRole' => 'Select at least 1 role.',
    'atleastOneCategory' => 'Select at least 1 category.',
    'selectOccassion' => 'If occassion not select then checked day name will be Occassion name',
    'clientFilterVerification' => 'Client filter according verification',
    'fileMessage' => 'The Message field is requried',
    'halfDayAlreadyApplied' => 'Half day leave already applied on this date, do you want to reject it?',
    'fullDayAlreadyApplied' => 'Full day leave already applied on this date, do you want to reject it?',
    'leaveAlreadyApplied' => 'Leaves are already applied for one or more of the selected dates, do you want to reject it?',
    'rejectIt' => 'Yes, Reject it!',
    'noteAddedSuccess' => 'Note added successfully.',
    'promotionAddedSuccess' => 'Promotion added successfully.',
    'promotionUpdatedSuccess' => 'Promotion updated successfully.',
    'welcome' => array(
        'message' => 'Welcome to the setup wizard',
        'title' => 'Welcome to the installer',
    ),
    'title' => 'Laravel installer',

    'next' => 'Following',
    'finish' => 'Install',
    'final' => array(
        'title' => 'Finalized.',
        'finished' => 'The application has been installed successfully!',
        'exit' => 'Click here to exit.',
    ),
    'currency' => array(
        'currencyPosition' => 'This controls the position of the currency symbol. like $1 or 1$ or $ 1 or 1 $',
        'thousandSeparator' => 'This sets the thousand separators of displayed prices. like $10,000 or $1000,0000',
        'decimalSeparator' => 'This sets the decimal separator of displayed prices. like $10.00 or $10,00',
        'numberOfdecimals' => 'This sets the number of decimal points shown in displayed prices. like $10.00 or $10.000',
    ),
    'noGroupAdded' => 'No group added.',
    'noRoleFound' => 'No role found.',
    'noLeaveTypeAdded' => 'No leave type added.',
    'whyArchive' => 'Archiving this leave prevents direct deletion, as the user has already taken it. Once archived, it can only be permanently deleted later.',
    'updateAlert' => 'Do not click update now button if the application is customized. Your changes will be lost.',
    'updateBackupNotice' => 'Take a backup of files and database before updating.',
    'fieldBlank' => 'Field cannot be blank.',
    'defaultRoleCantDelete' => 'Default role can not be deleted.',
    'reminderMailSuccess' => 'Reminder Mail sent successfully.',
    'smtpError' => 'Your SMTP details are not correct. Please update to the correct one',
    'smtpSuccess' => 'Your SMTP details are correct',
    'smtpSecureEnabled' => 'For Gmail SMTP configuration, please follow the following link ',
    'smtpNotSet' => 'You have not configured SMTP settings. You might get an error when adding info ',
    'smtpRecommendation' => 'Recommendation for SMTP ',
    'addStripeWebhookUrlHelpVisit1' => 'Visit <a href="https://dashboard.stripe.com/account/webhooks" target="_blank">Generate</a> Add endpoint as above url and enter the webhook key generated',
    'addStripeWebhookUrlHelpVisit2' => 'Select event <b>invoice.payment_failed, invoice.payment_succeeded , payment_intent.succeeded</b> and <b>payment_intent.payment_failed</b> while creating webhook.',
    'addPaypalWebhookUrl' => 'Add this webhook url on your paypal app settings.',
    'addFlutterwaveWebhookUrl' => 'Add this webhook url on your flutterwave app settings.',
    'addSquareWebhookUrl' => 'Add this webhook url on your square app settings.',
    'addRazorpayWebhookUrl' => 'Add this webhook url on your razorpay app settings.',
    'addPaystackWebhookUrl' => 'Add this webhook url on your paystack app settings.',
    'addPaystackCallbackUrl' => 'Add this callback url on your paystack app settings.',
    'gdprUpdated' => 'GDPR setting successfully updated',
    'invoiceCanNotDeleted' => 'Invalid Request You can not delete this invoice',
    'addDiscussion' => 'Message sent successfully.',
    'creditNoteAppliedSuccessfully' => 'Credit note applied successfully.',
    'pleaseEnterCreditAmount' => 'Enter at least one credit amount.',
    'creditNoteCanNotDeleted' => 'Credit Note cannot be deleted.',
    'noLeadAgentAdded' => 'No lead agent added.',
    'selectProduct' => 'Please select at least one product.',
    'noLeadAgent' => 'No Lead Agent Found',
    'noCommentFound' => 'No comment found.',
    'noNoteFound' => 'No note found.',
    'leaveApplySuccess' => 'Leave applied successfully.',
    'leaveApplyError' => 'Leave already applied for the selected date.',
    'holidayLeaveApplyError' => 'You can not apply for leave on holiday.',
    'errorOccured' => 'Some error occurred.',
    'noNotification' => 'No new notifications',
    'addGoogleCallback' => 'Add this callback url on your google app settings.',
    'addFacebookCallback' => 'Add this callback url on your facebook app settings.',
    'addLinkedinCallback' => 'Add this callback url on your linkedin app settings.',
    'addTwitterCallback' => 'Add this callback url on your twitter app settings.',
    'clockOutTimeError' => 'Clock-out time cannot be less than clock in time',
    'leaveTypeValueError' => 'No of leaves should be greater than or equal to Zero',
    'employeeLeaveQuota' => 'No of leaves should be greater than or equal to Zero and should be greater than leaves taken',
    'maxClockin' => 'Maximum clock-ins reached.',
    'attendanceMarked' => 'Attendance has been already marked.',
    'amountIsZero' => 'Amount should be more than ZERO for the payment',
    'taskAfterDateValidation' => 'Task end date should not be less than the task start date',
    'taskBeforeDateValidation' => 'Task end date should not be greater than the milestones end date',
    'selectAnotherStatus' => 'The task cannot be stored with this status when no project is selected. Please select another status.',
    'selectStatus' => 'The selected project does not require approval from admin or project admin, so you cannot select the this status. Please select another status.',
    'noProductSubCategoryAdded' => 'No product sub-category added.',
    'pinnedSuccess' => 'Pinned successfully',
    'noInvoiceFound' => 'Seems like no invoice has been generated.',
    'noClientFound' => 'Seems like no client exists. Please create the client first',
    'noTaskFound' => 'Seems like no task exists. Please create the task first',
    'noTaskFilesFound' => 'Seems like no task files uploaded.',
    'noEmployeesFound' => 'Seems like no employees exist. Please create the employee first',
    'noEstimatesFound' => 'Seems like no estimates exist. Please create the estimate first',
    'noInvoicesFound' => 'Seems like no invoices exist. Please create the invoice first',
    'noExpensesFound' => 'Seems like no expenses exist. Please create the expense first',
    'noTicketsFound' => 'Seems like no tickets exist.',
    'noLeadFound' => 'Seems like no leads exist. Please create the leads first',
    'noNoticeFound' => 'Seems like no notice exists.',
    'noLeavesFound' => 'Seems like no leaves exist.',
    'noProjectAssigned' => 'No project assigned to you.',
    'noAttendanceDetailToday' => 'No attendance detail for today.',
    'noSpacePlease' => 'No space please!',
    'confirmation' => array(
        'createCreditNotes' => 'Are you sure that you want to create the credit note?',
        'orderStatusChange' => 'Are you sure you want to change the order status?',
        'rejectConfirm' => 'Yes, reject',
    ),
    'invoiceSentSuccessfully' => 'Invoice sent Successfully',
    'offlineInvoiceApproved' => 'Offline Invoice Approved Successfully',
    'estimateSentSuccessfully' => 'Estimate sent Successfully',
    'invoiceMarkAsSent' => 'Invoice Mark as Sent Successfully',
    'deleteField' => 'You will not be able to recover the deleted field!',
    'confirmCancel' => 'Confirm Cancel!',
    'estimateCancelText' => 'Do you want to cancel this estimate!',
    'selectAction' => 'Select Action',
    'abortAction' => 'The uploaded file contains no valid data.',
    'notEnoughData' => 'Not enough data',
    'newMilestoneCreated' => 'New milestone created',
    'milestoneUpdated' => 'Milestone Updated',
    'milestoneDeleted' => 'Milestone Deleted',
    'selectConversation' => 'Select a conversation to send a message',
    'discountExceed' => 'Discount cannot be more than total amount.',
    'proposalSendSuccess' => 'Proposal sent Successfully.',
    'totalTimeZero' => 'End time should be greater than start time.',
    'contractRenewSuccess' => 'Contract renewed successfully.',
    'signatureRequired' => 'Signature is required.',
    'estimateSigned' => 'Estimate accepted successfully.',
    'adminPermissionError' => 'Admin permissions cannot be changed.',
    'newEmployeeInfo' => 'According to date of joining.',
    'leaveInfo' => 'According to date of leave.',
    'employeeExitInfo' => 'According to date of exit.',
    'unresolveTicketInfo' => 'Tickets with status Pending or Open.',
    'unassignTicketInfo' => 'Tickets which are not assigned to an agent.',
    'themeChangesReset' => 'All custom theme changes will reset.',
    'permissionDenied' => 'Permission Denied.',
    'accessDenied' => 'Access Denied.',
    'forbidden' => 'Forbidden',
    'pageNotFound' => 'Page not found.',
    '404Title' => 'Error 404 (Not Found)',
    'inviteEmailSuccess' => 'Invitation sent successfully.',
    'acceptInviteError' => 'Invalid invitation. You are not authorised to sign up.',
    'signupSuccess' => 'Sign up successfully. You will be redirected to your dashboard in a while',
    'inviteLinkSuccess' => 'Invitation link created successfully.',
    'installingUpdateMessage' => 'Installing...Please wait (This may take a few minutes.)',
    'installedUpdateMessage' => 'Installed successfully. Reload the page to see the changes.',
    'consentOptIn' => 'Consent Opt In Successfully.',
    'consentOptOut' => 'Consent Opt Out Successfully.',
    'inviteInfo' => 'Employees will receive an email to log in and update their profile through the self-service portal.',
    'taskDependentDate' => 'Dependent task due date cannot be in future.',
    'assignClientFirst' => 'You need to assign a client to the project.',
    'invalidOrInactiveAccount' => 'Email not found or account is inactive. Please check your email.',
    'viewKey' => 'Click Here to View Key',
    'testMailSentSuccessfully' => 'Test mail sent successfully',
    'fileUploaded' => 'File uploaded successfully. Click view file to view the uploaded file',
    'filesMoveToAwsSuccessfully' => 'Files successfully moved to AWS S3',
    'allFilesMovedtoAws' => 'All Files are already moved to AWS S3',
    'primaryColorRequired' => 'Primary color is required.',
    'settingModuleCannotBeDisabled' => 'Setting  module cannot be disabled.',
    'paymentSuccessful' => 'Payment Successful.',
    'darkThemeRestrictionInfo' => 'Theme color settings will not work when Dark Mode is active.',
    'cronIsNotRunning' => 'It appears that your cron job has not run in the last 48 hours. Please check to ensure that it is properly configured. This message will automatically disappear once the cron job is functioning correctly again.',
    'resolveTicketInfo' => 'Tickets with status Closed or Resolved.',
    'invoicePaymentExceedError' => 'Payment amount cannot be more than invoice due amount.',
    'paymentFailed' => 'Payment Failed.',
    'invalidPayload' => 'Invalid Payload.',
    'invalidSignature' => 'Invalid Signature.',
    'webhookHandled' => 'Webhook Handled.',
    'projectDetailsNotAdded' => 'Project details not added.',
    'inviteLinkCopied' => 'Invite Link Copied.',
    'unsentInvoiceInfo' => 'The Invoice cannot be paid until the invoice is sent to the customer.',
    'selectCustomerForBillingAddress' => 'Select the client to show billing address.',
    'invoicesWidgetMessage' => 'Invoices are shown based on date of creation of invoices.',
    'estimatesWidgetMessage' => 'Estimates are shown based on due date of estimates.',
    'proposalsWidgetMessage' => 'Proposals are shown based on date of creation.',
    'holidayDataNotFound' => 'Data not found for mark holiday.',
    'codeSent' => 'Two-factor verification code sent to email.',
    'codeNotMatch' => 'The two-factor code you have entered does not match.',
    'resendCode' => 'You have received an email that contains two-factor login code. If you have not received it, ',
    'noConsentFound' => 'No Consent found.',
    'proposalInfo' => 'Proposals are for Leads. If you want to create for existing clients, then create Estimate.',
    'twoFaAppInfo' => 'Enter the code from the two-factor app on your mobile device. If you\'ve lost your device, you may enter one of your recovery codes.',
    'sessionDeleteConfirmation' => 'All the logged-in users will be logged out.',
    'requiredForLogin' => 'This field is required for user login.',
    'showHidePurchaseCode' => 'Show or hide purchase code',
    'changePurchaseCode' => 'Change purchase code',
    'enable2FAUsingEmail' => 'Enabling this feature will send code on your email account <b>:email</b> for log in.',
    'enable2FAUsingAuthenticator' => 'Use the Authenticator app to get free verification codes, even when your phone is offline. Available for Android and iPhone.',
    'approvalWarning' => 'User will be able to access the account.',
    'invalid2FaCode' => 'Invalid 2FA Code.',
    'downloadFilefromCodecanyon' => 'Download the zip file from codecanyon and upload it here. Only .zip file type is allowed for uploading.',
    'phpUpdateRequired' => 'PHP version update is required',
    'invalidEmailFormat' => 'Invalid email format.',
    'calculateTaxBeforeDiscount' => 'Note : Tax is calculating before discount.',
    'calculateTaxAfterDiscount' => 'Note : Tax is calculating after discount.',
    'proposalMarkAsSent' => 'Proposal Mark as Sent Successfully',
    'filesMoveToCloudSuccessfully' => 'Files successfully moved to cloud storage.',
    'allFilesMovedToCloud' => 'All Files are already moved to cloud storage.',
    'unitDeleteError' => 'You cannot delete this unit as it is associated with finance and product items. Dissociate the unit from all items and try again.',
    'fileFormat' => array(
        'ImageFile' => 'only .jpg, .jpeg, .png, .svg formats are allowed.',
        'multipleImageFile' => 'only .txt, .pdf, .doc, .xls, .xlsx, .docx, .rtf, .png, .jpg, .jpeg formats are allowed.',
    ),
    'leaveFileMessage' => 'You can attach the receipt of the prescription, doctor visit or travel document etc',
    'matchColumnMessage' => 'Please sort the data you have uploaded by matching the columns in the CSV to the fields in the associated fields.',
    'columnMatchSuccess' => '<strong>Well done!</strong> You have successfully matched all the columns. Please click on submit to save.',
    'requiredColumnsUnmatched' => 'Following fields are required and must be matched: <strong>:columns</strong>',
    'unmatchedColumns' => '<span id="unmatchedCount">:unmatchCount</span> unmatched columns.',
    'pleaseSelectAColumn' => 'Please select a column or click on skip',
    'pleaseSelectCategory' => 'Please select a Category',
    'importUploadSuccess' => 'Data uploaded successfully.',
    'importProcessStart' => 'Import process started. Please wait.',
    'confirmResetPermission' => 'This will reset permissions for all users with this role. Do you want to reset?',
    'invoiceDueOn' => 'Invoice Due On',
    'googleCalendar' => array(
        'confirmRemove' => 'Are you want to disable Google Calendar ?',
        'yesRemove' => 'Yes, Remove it!',
        'removedSuccess' => 'Google Calendar removed successfully.',
        'AuthorizedRedirectURI' => 'Authorized redirect URIs',
        'AuthorizedRedirectURIInfoMessage' => 'Users will be redirected to this path after they have authenticated with Google. The path will be appended with the authorization code for access, and must have a protocol. It can’t contain URL fragments, relative paths, or wildcards, and can’t be a public IP address.',
        'addGoogleCalendarUrl' => 'Add this redirect URI to your Google Console',
        'notificationTitle' => 'Notification Settings',
        'verifiedSuccess' => 'Google calendar settings verified successfully.',
        'updatedSuccess' => 'Google calendar settings updated successfully.'
    ),
    'databasebackup' => array(
        'note' => 'Note: Due to the limited execution time and memory available to PHP, backing up very large databases may not be possible. If your database is very large you might need to backup directly from your SQL server via the command line, or have your server admin do it for you if you do not have root privileges.',
        'backupNotExist' => 'Backup file doesn\'t exist.',
        'backupDeleted' => 'Successfully deleted backup!',
        'backedupSuccessful' => 'The database backup has been added to the queue. It will start to appear here once the next cron job runs successfully.',
        'databaseError' => 'Database error',
        'createDatabaseBackupAlert' => 'Do you want to create Database Backup!',
        'confirmCreateDatabaseBackup' => 'Yes, Create It!',
        'info' => 'Note: Create a backup every :everyDayCount days at :time, auto delete backups older than :olderDayCount days (set -1 to disable) ',
    ),
    'notAllowedToAssignAdminPermission' => 'You\'re not allowed to assign admin role.',
    'downloadable' => 'Downloadable product gives access to a file upon purchase',
    'invalidData' => 'Invalid Data : ',
    'invalidDate' => 'Invalid Date Format : ',
    'duplicateEntryForEmail' => 'Duplicate Entry for Email : ',
    'duplicateEntryForEmployeeId' => 'Duplicate Entry for Employee ID : ',
    'employeeNotFound' => 'Employee not found',
    'dragDropScreenInfo' => 'Drag and drop will work on desktop devices only.',
    'timerPausedSuccessfully' => 'Timer paused successfully.',
    'orderStatusChanged' => 'Order status changed successfully.',
    'orderStatus' => array(
        'pending' => 'Pending order is ready to collect payment.',
        'onHold' => 'On hold order is waiting for payment or payment is pending.',
        'failed' => 'Failed order is failed to collect payment.',
        'processing' => 'Processing order is in process.',
        'completed' => 'Completed an order will create invoice and payment of order.',
        'canceled' => 'Canceled an order is canceled and can\'t be processed.',
        'refunded' => 'Refunded an order will create credit note of order.',

    ),
    'employeeEmergencyContact' => 'Emergency contact saved successfully.',
    'sameCurrencyInvoiceNote' => 'Only same currency Invoices will show here.',
    'alreadySigned' => 'Already signed',
    'invoiceAlreadyPaid' => 'Invoice already paid',
    'currencyExchangeKeyNotFound' => 'Currency Converter Key Not Found',
    'noUnpaidInvoiceFound' => 'No unpaid invoice found.',
    'leaveLimitError' => 'Leave limit exceeded for the selected leave type.',
    'remainingLeaveError' => 'Only :leave leave remaining for the selected leave type.',
    'multipleRemainingLeaveError' => 'Only :leaves leaves remaining for the selected leave type.',
    'monthlyLeaveLimitError' => 'Monthly Leave limit exceeded for the selected leave type.',
    'employeeShiftAdded' => 'Employee Shift Saved.',
    'removeShiftText' => 'All the employees related to this shift will be moved to the default shift.',
    'defaultLanguageCantChange' => 'To modify the default language, please navigate to the :appsettings. The current language is set as the default.',
    'defaultEnLanguageCantChange' => 'Modifying English language not permitted, but can be enabled/disabled.',
    'requestSubmitSuccess' => 'Request submitted successfully.',
    'existingShiftOverride' => 'The existing shift will be overridden.',
    'leadFollowUpRestricted' => 'Follow-up is disabled for this user.',
    'clockInNotAllowed' => 'Clock In Not Allowed.',
    'roleNotAssigned' => 'Role is not assigned.',
    'archivedTaskNotWork' => 'You will not be able to act on archived project tasks.',
    'totalEmployeeInfo' => 'Total employees in the company. Date filter not applied.',
    'dateFilterNotApplied' => 'Date filter not applied.',
    'youAreOnLeave' => 'You are on leave today.',
    'holidayToday' => 'Today is a Holiday.',
    'languageEnabledAlertMessage' => 'Simply enabling a language setting will not automatically change the language. To effectively change the language, you must also have translations available in that specific language.',
    'mailSettingSelectMessage' => 'We recommend using <b>SMTP</b>. Mail settings might not work on every server which also results in emails landing to SPAM. Please also check the test email if your mail server is working or not',
    'customPermissionError' => 'Permissions have been customised for this user.',
    'congratulationNewAward' => 'Congratulation for :award award',
    'appreciationPhoto' => 'Photo taken while presenting the award',
    'disableIt' => 'Inactive It',
    'recoverAwardRecord' => 'You have :employeeCount employees awarded by this award. You will not be able to recover the deleted employees awarded record!',
    'loginDetailsEmailed' => 'Login details will be emailed to this email',
    'notAllowedToDeleteCurrency' => 'You are not allowed to delete this currency as it has been used in other places.',
    'appNameToolTip' => 'This will be visible to the left sidebar top and on login page',
    'darkThemeLogoTooltip' => 'This logo will be shown when you change the theme to dark mode',
    'lightThemeLogoTooltip' => 'This logo will be shown when you change the theme to light mode',
    'configureCurrencyConverterKey' => 'You need to configure the Currency converter key first to fetch Latest exchange rate. :link to add key',
    'noticePeriodMessage' => 'Notice Period Ends On',
    'probationMessage' => 'Probation Ends On',
    'internshipMessage' => 'Internship Ends On',
    'contractMessage' => 'Contract Ends On',
    'probationEndDate' => "Enter the end date when the employee's probation is going to end and he/she is going to be the part of company permanently",
    'noticePeriodStartDate' => 'Enter the start date when an employee is going to be in the notice period before leaving the company',
    'noticePeriodEndDate' => 'If the notice period date is in the future, the employee will automatically be marked as inactive on that date, and if the exit date is empty, it will be filled accordingly.',
    'lastDateTooltip' => 'If the exit date is in the future, the employee will be automatically marked inactive on that date. And if the exit date is in the past and the employee is set as active, they will be marked inactive by the next cron job.',
    'googleMapMessage' => 'You need to add google map Key to see the Maps here and locate your location directly to map. Visit',
    'googleMapRemove' => 'Leave blank to remove a Google map key',
    'googleMapTooltip' => 'You can add the location on to map in <b>:route</b> once google map setting is configured',
    'googleMapLocationAddedTooltip' => 'Latitude and longitude added for this address',
    'invoiceLogoTooltip' => 'This logo will appear on the invoices (only .jpg, .jpeg, .png formats are allowed)',
    'companyNameTooltip' => 'Add the full name of your company. The company name visible to the left sidebar will be changed from theme setting',
    'sendMonthlyReportTooltip' => 'The email will include the attendance details of all employees for the selected month.',
    'defaultAddressInfo' => 'The attendance and other modules utilize the default business address, but when creating records, you have the option to select a different address as default address',
    'bankTransactionSuccess' => 'Bank Transaction Success',
    'selectBank' => 'Select bank account',
    'selectDate' => 'Select Date',
    'pusherError' => 'Your Pusher details are not correct. Please update to the correct one',
    'pusherSuccess' => 'Your Pusher details are correct',
    'authorisedSignatorySignatureTooltip' => 'This signature will appear on the paid invoices (only .jpg, .jpeg, .png formats are allowed). Check Show Authorised Signatory from the bottom of the invoice setting page',
    'invoiceStatusShowTooltip' => 'This will show the invoice status (paid/unpaid/partial paid) on the invoice pdf',
    'invoiceAuthorisedSignatoryShowTooltip' => 'This will show the authorised signatory on the invoice pdf if the signature is uploaded and invoice status is paid.',
    'projectCopiedSuccessfully' => 'Project Copied Successfully',
    'quickBooksCredentialsIncorrect' => 'QuickBooks credentials are incorrect.',
    'quickBooksConnectSuccess' => 'QuickBooks account is connected.',
    'cacheClear' => 'Successfully cleared cache.',
    'leadStatusChangeSuccess' => 'Lead Status Change Successfully',
    'calculateTaskProgress' => 'We calculate progress on task completion',
    'emailCannotChange' => 'Email cannot be changed as it is registered with other companies also.',
    'accessDeniedMessage' => 'We\'re sorry, but it appears that the link you were trying to access has expired. This could be due to a variety of reasons, such as the content being removed or updated, the link being deactivated, or the link having a limited timeframe for access',
    'markSentInfo' => 'Client will not receive any email.',
    'enableClientModule' => 'Enable Client Module to access this section.',
    'overwriteAttendanceTooltip' => 'This will delete the existing attendance and will create new attendance record for the selected duration',
    'brandingStyleToolTip' => 'Below branding style will work for left sidebar top and on login page.',
    'leave' => array(
        'noOfYearlyLeaves' => 'This field is designated to set the number of leaves provided to employees annually. ',
        'noOfMonthlyLeaves' => ' This field is designated to set the number of leaves provided to employees for a month.',
        'allowedNotice' => 'Check this if you want to allow employees in the <b>Notice Period</b> to apply for leaves of this type.',
        'allowedProbation' => 'Check this if you want to allow employees in the <b>Probation</b> to apply for leaves of this type.',
        'unusedLeave' => 'Determines how the unused leaves are treated at the end of the year.<br><br><b>Carry Forward</b>: Unused leaves will be added to next year leaves.<br><br><b>Lapse</b>: Unused leaves will simply lapse and no action will be taken.<br><br><b>Paid</b>: Employee will be paid salary of the number of days equivalent of unused leaves.<br><br><b>Note</b>: This will not change after creating the leave type.',
        'effectiveAfter' => 'This leave type will be effective after the number of days or the number of month of employee\'s joining. <br><br>Leave blank to allow from date of joining.',
        'gender' => 'Leave Type can only be used by selected <b>Gender</b> employees and other employees will not be able to apply for leaves with this leave type',
        'maritalStatus' => 'Leave Type can only be used by selected <b>Marital Status</b> employees and other employees will not be able to apply for leaves with this leave type',
        'department' => 'Leave Type can only be used by selected <b>Department</b> employees and other employees will not be able to apply for leaves with this leave type',
        'designation' => 'Leave Type can only be used by selected <b>Designation</b> employees and other employees will not be able to apply for leaves with this leave type',
        'role' => 'Leave Type can only be used by selected <b>Role</b> and other role will not be able to apply for leaves with this leave type',
        'noOfLeaves' => 'Number of leaves of this type given to each employee per year. For example, your company may give 10 sick leaves per year',
        'monthlyLimit' => 'The maximum number of leaves of this type an employee can take per month.',
        'paidStatus' => 'This leave type will be paid or unpaid for all the employees',
        'overutilization' => 'This option handles the overutilization of this leave type.<br><br><b>Do not allow</b>: Overutilization of this leave type is NOT ALLOWED.<br><br><b>Allow and Mark Paid</b>: Overutilization of this leave type is allowed and extra leaves will be marked as PAID.<br><br><b>Allow and Mark Unpaid</b>: Overutilization of this leave type is allowed but extra leaves will be marked as UNPAID.',
    ),
    'noTicketChannelAdded' => 'No Ticket Channel Added',
    'roleNotFound' => 'Role not found for :user',
    'signUpUrlRequired' => 'The terms link field is required when sign up terms is enabled.',
    'adminPermissionsCantChange' => 'Admin permissions can not be changed',
    'customModuleInstalled' => 'Module installed successfully. You will be redirected to the custom module page. Activate the module to use it.',
    'deal' => array(
        'deletePipeline' => 'It has :stages stages and :deals deals. The all records will be deleted permanently.',
        'deleteStage' => 'The all deals of this stage will be shifted into default stage.'
    ),
    'leadConversion' => 'Data is showing total records and link will show only default pipeline records.',
    'totalDealWidget' => 'Link will show default pipeline deals.',
    'currencyConvertKeyUpdated' => 'The Currency Converter Key Updated',
    'clientSignUpDisabledByAdmin' => 'Client sign up is disabled by admin.',
    'cantAddFollowup' => 'You can not add followup. If deal is win or lost.',
    'lowerValue' => 'Enter lower value than',
    'leaveTypeNotAllowed' => 'Leave type not allowed for this employee.',
    'noLeaveApplyForSelectedDate' => 'Please select another date. There is holiday on selected date.',
    'leaveRejectedByNewLeave' => 'Leave rejected by new leave application. You have applied for new leave on the same date.',
    'leaveQuotaReport' => 'Leave Quota Report is only for Current year :start to :end',
    'descriptionFieldRequired' => 'The description field is required.',
    'agentFieldRequired' => 'The agent field is required.',
    'unassignedTask' => 'The project :has :unassigned unassigned :task. To show unassigned :task',
    'addShift' => 'Add at-least 1 shift in rotation sequence.',
    'rotationStatusChanged' => 'Rotation status changed successfully',
    'employeeRotationChanged' => 'Rotation changed successfully',
    'employeeRemoveSuccess' => 'Employee removed successfully from rotation.',
    'rotationNotFound' => 'Rotation not found',
    'fileNotFound' => 'File not found',
    'automateShiftAdded' => 'Automate Shift Saved.',
    'rotationEmpRemove' => 'Do you really want to remove employee from rotation!',
    'uploadOtherInvoice' => 'Upload an image for reference or documentation purposes.',
    'selectRunRotation' => 'You can select and run the shift rotations.',
    'noShiftRotation' => 'Select at least one rotation',
    'rotationRunSuccessfully' => 'Shift rotation(s) successfully assigned.',
    'noData' => 'No data available in table',
    'totalShiftHours' => 'These are the minimum hours required by employee to clockin in a day for full attendance.',
    'halfdayShiftHours' => 'These are the minimum hours required by employee to clockin in a day for half day attendance. If clocked hours are less than half day hours than absent will be marked.',
    'leaveApplied' => 'Leave is applied for today.',
    'leaveForFirstHalf' => 'Leave is applied for the first half.',
    'leaveForSecondHalf' => 'Leave is applied for the second half.',
    'todayHoliday' => 'Today is Holiday.',
    'notInOfficeHours' => 'You are not within office hours.',
    'shiftNotAssigned' => 'No shift is assigned for today.',
    'halfdayHoursNotComplete' => 'You have not completed enough hours to mark half day. If you clockout now, absent will be marked.',
    'willMarkHalfDay' => 'You have not completed total shift hours yet. If you clockout now, half day will be marked.',
    'SelectaDesignation' => 'Select a current designation.',
    'SelectaDepartment' => 'Select a current department.',
    'changeWeeklyTimesheetStatusConfirmation' => 'Are you sure you want to change the status of this weekly timesheet?',
    'submitWeeklyTimesheetConfirmation' => 'Are you sure you want to submit this weekly timesheet? You will not be able to edit it later.',
);
