<?php
// SAAS
return [
    'superAdminDashboard' => 'Super Admin Dashboard',
    'loginLogoBackgroundColor' => 'Login Screen Logo background Color',
    'frontWebsiteLogo' => 'Front Website Logo',
    'frontWebsiteLogoToolTip' => 'This logo will be shown to front website',
    'package' => 'Package',
    'skipAll' => 'Skip All',
    'showSkippedColumns' => 'Display Skipped Columns',
    'btnBack' => 'Back',
    'issue_date' => 'Issue Date',
    'invoiceNo' => 'Invoice Number :',
    'ticketAddSuccess' => 'Ticket added successfully',
    'btnSave' => 'Save',
    'skip' => 'Skip',
    'monthly' => 'Monthly Plan',
    'annual' => 'Annual Plan',
    'paymentSuccessfullyDone' => 'You have successfully subscribed :package :planType plan.',
    'paymentProcessing' => 'You payment is processing for :package :planType plan. we will notify you once it is done.',
    'noPaymentOptionEnable' => 'No payment option are enabled.',
    'willNotBeImported' => 'will not be Imported',
    'selectAColumn' => 'Select a column',
    'doNotCloseOrRefreshPage' => 'Do not close or refresh this page until the import is complete',
    'importFailedJobs' => ':failedJobs entries failed of :totalJobs entries in the import.',
    'maxActiveEmployee' => 'Max :maxEmployees Active Employees',
    'importInProgress' => 'Import in progress...',
    'pleaseWait' => 'Please wait...',
    'importProcessedJobs' => ':processedJobs entries processed of :totalJobs entries in the import.',
    'importCompleted' => 'Import completed',
    'exceptions' => 'Exceptions while importing',
    'importExcelInfo' => 'Date format should be in Y-m-d (e.g. 2022-04-21] format. Make sure the date format is correct in the excel file.',
    'importAttendanceExcelInfo' => 'Datetime format should be in Y-m-d H:i:s (e.g. 2022-04-21 12:00:00] format. Make sure the date format is correct in the excel file.',
    'importProjectExcelInfo' => 'Date format should be in Y-m-d (e.g. 2022-04-21] format. Make sure the date format is correct in the excel file.',
    'backToEmployees' => 'Back to Employees',
    'backToClient' => 'Back to Clients',
    'backToAttendance' => 'Back to Attendance',
    'backToLead' => 'Back to Leads',
    'backToProject' => 'Back to Projects',
    'crop' => 'Crop',
    'pay' => 'Pay',
    'choosePaymentMethod' => 'Choose Payment Method',
    'choseFreePlan' => 'Do you want to choose this free plan.',
    'choseDefaultPlan' => 'Do you want to choose this default plan.',
    'cropImage' => 'Crop Image',
    'dragImage' => 'Drag Image',
    'rotateLeftImage' => 'Rotate Left Image',
    'rotateRightImage' => 'Rotate Right Image',
    'downloadable' => 'Downloadable',
    'downloadableFile' => 'Downloadable File',
    'unmatchedColumn' => 'Unmatched Column',
    'orderMarkAsComplete' => 'Mark as complete',
    'unlimited' => 'Unlimited',
    'annual_price' => 'Annual Price',
    'monthly_price' => 'Monthly Price',
    'fileStorage' => 'File Storage',
    'module_in_package' => 'Module in Package',
    'gb' => 'GB',
    'mb' => 'MB',
    'maxStorageSize' => 'Max Storage Size',
    'max' => 'Max',
    'storageUnit' => 'Storage Unit',
    'usedStorage' => 'Storage Used',
    'freePlan' => 'Free Plan',
    'autoRenew' => 'Auto Renew',
    'position' => 'Position No.',
    'company' => 'Company',
    'offlinePlanChange' => 'Offline Plan Change',
    'paymentBy' => 'Payment By',
    'lastActivity' => 'Last Activity',
    'subDomain' => 'SubDomain',
    'employeeQuota' => 'Employee Quota',
    'storage' => 'Storage',
    'notUsed' => 'Not Used',
    'packageType' => 'Package Type',
    'packageValidFor' => 'Package Valid For',
    'paymentDate' => 'Payment Date',
    'nextPaymentDate' => 'Next Payment Date',
    'licenceExpiresOn' => 'Licence Expires On',
    'flowId' => 'Flow Id',
    'smsTemplateCopied' => 'SMS Template Copied',
    'requestedForCompany' => 'Requested for Company',
    'selectTheme' => 'Select Theme',
    'theme' => 'Theme',
    'signup' => 'Signup',
    'frontFeatureSettings' => 'Front Feature Settings',
    'feature' => 'Feature',
    'htmlOrEmbeded' => 'Html/Embed for contact page',
    'registrationOpen' => 'Registration Open',
    'recommended' => 'Recommended',
    'selectIcon' => 'Select icon',
    'type' => 'Type',
    'header' => 'Header',
    'headerFooterBoth' => 'Header And Footer Both',
    'changeToPosition' => 'Position',
    'authCss' => 'Auth Css',
    'question' => 'Question',
    'answer' => 'Answer',
    'googleCalender' => 'Enable Google Calender',
    'accountDetails' => 'Account Details ( First company admin )',
    'superAdminPanelTheme' => 'Super Admin Panel Theme',
    'types' => [
        'image' => 'Image',
        'icon' => 'Icon',
        'task' => 'Task',
        'bills' => 'Bills',
        'team' => 'Team',
        'apps' => 'Apps',
    ],
    'menu' => [
        'packages' => 'Packages',
        'companies' => 'Companies',
        'adminFaq' => 'Admin FAQ',
        'superAdmin' => 'Super Admin',
        'offlineRequest' => 'Offline Request',
        'supportTicket' => 'Support Ticket',
        'frontSettings' => 'Front Settings',
        'frontSettingsTranslation' => 'Front Settings Translation',
        'featureTranslation' => 'Feature Translation',
        'frontThemeSettings' => 'Front Theme Settings',
        'featureWithImage' => 'Feature With Image',
        'featureWithIcon' => 'Feature With Icon',
        'frontMenuSettings' => 'Front Menu Settings',
        'frontWidgets' => 'Header & Footer Scripts',
        'seoDetails' => 'SEO Details',
        'authSetting' => 'Auth Settings',
        'signUpSetting' => 'Sign Up Settings',
        'signUpTranslation' => 'Sign Up Translation',
        'testimonialSetting' => 'Testimonial Settings',
        'testimonial' => 'Testimonial',
        'testimonialSettingTranslation' => 'Testimonial Settings Translation',
        'clientSetting' => 'Client Settings',
        'clientSettingTranslation' => 'Client Settings Translation',
        'frontClient' => 'Front Client',
        'faqSetting' => 'FAQ Settings',
        'faqSettingTranslation' => 'FAQ Settings Translation',
        'faq' => 'FAQ',
        'contactSetting' => 'Contact Settings',
        'priceSetting' => 'Price Settings',
        'footerSetting' => 'Footer Settings',
        'ctaSetting' => 'CTA Settings',
        'featurePageApps' => 'Feature Page Application',
        'featurePageAppsTranslation' => 'Feature Page Application Translation',
        'featurePageSetting' => 'Feature Page Settings',
        'setting' => 'Settings',
        'billing' => 'Billing',
        'features' => 'Features',
        'pricing' => 'Pricing',
        'contact' => 'Contact',
        'planDetails' => 'Plan Details',
        'purchaseHistory' => 'Purchase History',
        'offlinePlanChange' => 'Offline Plan Change',
        'contactSubmit' => 'Contact Submit',
        'superadmin' => 'Superadmin',
    ],
    'dashboard' => [
        'totalCompany' => 'Total Companies',
        'activeCompany' => 'Active Companies',
        'licenseExpired' => 'License Expired',
        'inactiveCompany' => 'Inactive Companies',
        'totalPackages' => 'Total Packages',
        'recentRegisteredCompanies' => 'Newly Registered Companies',
        'recentSubscriptions' => 'Recent Paid Subscriptions',
        'recentLicenceExpiredCompanies' => 'Recent Licence Expired Companies',
        'companiesWithMostUsers' => 'Companies With Most Users',
        'packageCompanyCount' => 'Package Company Count',
        'registrationsChart' => 'Company Registrations',
    ],
    'packages' => [
        'packages' => 'Packages',
        'create' => 'Create Package',
        'edit' => 'Edit Package',
        'maxStorageSizeHelp' => 'Set -1 for unlimited storage size',
        'stripeAnnualPlanId' => 'Stripe Annual Plan ID',
        'stripeMonthlyPlanId' => 'Stripe Monthly Plan ID',
        'razorpayAnnualPlanId' => 'Razorpay Annual Plan ID',
        'razorpayMonthlyPlanId' => 'Razorpay Monthly Plan ID',
        'paystackAnnualPlanId' => 'Paystack Annual Plan ID',
        'paystackMonthlyPlanId' => 'Paystack Monthly Plan ID',
        'privateInfo' => 'Customers will not have visibility of the private package, but the superadmin can assign it to them through the superadmin panel',
        'recemmendedInfo' => 'Select this option if you wish to recommend the package to customers. It will be emphasized for their attention.',
        'isRecommended' => 'Mark as recommended',
        'licenseExpiresOn' => 'Licence Expires On',
        'trialExpiresOn' => 'Trial Expires On',
        'paymentGatewayPlans' => 'Payment Gateway Plans',
        'selectModule' => 'Select Modules for this package',
        'freePlanInfo' => 'Companies can upgrade to it without incurring any cost, and there is no requirement to provide payment gateway information.',
        'maxEmployeesInfo' => 'Enter the maximum number of employees permitted for this package.',
        'positionInfo' => 'Insert the sequence number for the display of this package in the list.',
        'defaultPackageCannotDelete' => 'This package cannot be deleted',
        'trialPeriod' => 'Trial Period:',
        'defaultMessage' => '<p>When trial Package gets expired, the company goes back to this plan</p>
<p>When company fails the payment of upgraded package, company goes back to this plan</p><p>This package cannot be deleted</p>',
        'trialMessage' => '<p>This is a trial package. If this package is active, then the company which register for the first time goes to this package</p><p>This package cannot be deleted</p>',
        'trialMessageTitle' => 'Trial Message shown on front page',
        'currentPlan' => 'Current Plan',
        'upgradePlan' => 'Upgrade Plan',
        'manageEmployees' => 'Manage Employees',
        'choosePlan' => 'Choose Plan',
        'defaultPlan' => 'Default Plan',
        'trialPeriodInfo' => 'Enter the number of days for trial period.',
        'notificationBeforeDays' => 'Notification Before Days',
        'notificationBeforeDaysInfo' => 'Enter the number of days before the package\'s expiration date that you wish to send a notification to the company.',
        'trialMessageInfo' => 'Enter the message to be displayed on the front page for the trial package.',
        'currency' => 'Package Currency',
        'currencyInfo' => 'Select the currency for this package. You can\'t change the currency once you have selected it.',
        'currencyEditInfo' => 'You can\'t change the currency once you have selected it. Because it will affect the existing companies subscription.',
        'yourDefaultPlan' => 'Your default plan.',
        'yourDefaultPlanInfo' => 'If your plan expires you will be assigned this package.',
        'choosePackageType' => 'Choose Package Type',
        'contactForBuy' => 'Contact for buy',
        'paidPlan' => 'Paid plan',
        'paidPlanInfo' => 'Companies will have to pay subscription price to upgrade to this package type.',
        'contactPlanInfo' => 'Companies will contact you via contact link you provide to purchase this package.',
        'contactButtontext' => 'Contact Button Text',
        'contactButtonUrl' => 'Contact Button URL',
        'name' => 'Package Name',
        'free' => 'Free',
        'freeForever' => 'Free forever',
        'private' => 'Private',
        'daysLeftTrial' => 'days left on trial',
        'trialExpired' => 'Trial expired',
        'selectPackage' => 'Select Package',
    ],

    'superadmin' => [
        'create' => 'Create Superadmin',
        'verifyMail' => 'verify the Email',
        'edit' => 'Edit :name',
        'details' => 'Details',
        'verified' => 'Verified',
        'registerDate' => 'Register Date',
        'totalUsers' => 'Total Users',
        'recentRegisteredCompanies' => 'Newly Registered Companies',
        'recentSubscriptions' => 'Recent Subscriptions',
        'recentLicenseExpiredCompanies' => 'Recent Licence Expired Companies',
        'disableFrontendSite' => 'Disable Frontend Website',
        'setupHomepage' => 'Set Homepage',
        'defaultLanding' => 'Theme Home Page',
        'customUrl' => 'Custom URL',
        'loadCustomUrl' => 'Load Custom URL',
        'loginAsCompany' => 'Impersonate As Company',
        'needApproval' => 'Company Need Approval',
        'signUpTermLink' => 'Terms and conditions link',
        'showSignUpTerms' => 'Sign-up terms and conditions',
        'acceptTerms' => 'Accept our',
        'termsAndCondition' => 'terms and conditions',
        'signUpTermsNote' => 'Show sign-up terms and conditions on signup page for both themes',
        'needApprovalInfo' => 'The company must receive approval from the Superadmin to access the app, which can be granted through the company table.',
    ],
    'frontCms' => [
        'updateTitle' => 'Update Front Detail',
        'headerTitle' => 'Header Title',
        'frontDetail' => 'Front Detail',
        'featureDetail' => 'Feature Detail',
        'headerDescription' => 'Header Description',
        'mainImage' => 'Header Image',
        'featureTitle' => 'Feature Title',
        'featureDescription' => 'Feature Description',
        'priceDetail' => 'Price Detail',
        'priceTitle' => 'Price Title',
        'priceDescription' => 'Price Description',
        'contactDetail' => 'Contact Detail',
        'getStartedButtonShow' => 'Show get started button',
        'singInButtonShow' => 'Show sign-in button',
        'pickPlan' => 'Pick your plan',
        'perYear' => 'Per Year',
        'perMonth' => 'Per Month',
        'getStarted' => 'Get Started',
        'submitEnquiry' => 'Submit Enquiry',
        'socialLinks' => 'Social Links',
        'facebook' => 'Facebook',
        'twitter' => 'Twitter',
        'instagram' => 'Instagram',
        'dribbble' => 'Dribbble',
        'enterFacebookLink' => 'Enter Facebook Link',
        'enterTwitterLink' => 'Enter Twitter Link',
        'enterInstagramLink' => 'Enter Instagram Link',
        'enterDribbbleLink' => 'Enter Dribbble Link',
        'enterYoutubeLink' => 'Enter Youtube Link',
        'enterSocialLinks' => 'Please enter social links in',
        'socialLinksNote' => 'Note: Leave the input blank to hide it on the Home Page',
        'primaryColor' => 'Primary Color',
        'widgetName' => 'Widget Name',
        'widgetCode' => 'Widget Code',
        'seoDetails' => 'SEO Details',
        'seo_title' => 'Meta title',
        'seo_author' => 'Meta author',
        'seo_description' => 'Meta description',
        'seo_keywords' => 'Keywords',
        'customCss' => 'Custom Css',
        'defaultLanguage' => 'Default Language',
        'commonSettings' => 'Common Settings',
        'youtube' => 'Youtube',
        'footerScript' => 'Script in Footer',
        'headerScript' => 'Script in Header',
        'setupHomepageBannerBackground' => 'Set homepage banner background',
        'setBackgroundColor' => 'Set background color',
        'setBackgroundImage' => 'Set background image',
        'setBackgroundImageColor' => 'Set background image with color overlay',
    ],
    'footer' => [
        'footer' => 'Footer',
        'setting' => 'Footer Menu Setting',
        'addFooter' => 'Add Footer Menu',
        'editFooter' => 'Edit Footer Menu',
        'footerCopyrightText' => 'Footer Copyright Text',
        'addFooterMenu' => 'Add Footer Menu',
        'editFooterMenu' => 'Edit Footer Menu',
    ],
    'footerSettings' => [
        'useDescription' => 'Use Description',
        'useExternalLink' => 'Use External Link',
        'pageContent' => 'Page Content',
        'externalLink' => 'External Link',
        'pageType' => 'Page Type',
        'public' => 'Public',
        'private' => 'Private',
        'pageLink' => 'Page Link',
        'copyLink' => 'Copy Link',
        'copyPageLink' => 'Copy Page Link',
    ],
    'messages' => [
        'removeTestimonialText' => 'This will remove the testimonial from the list.',
        'moduleBlank' => 'Select at-least 1 module',
        'alphabetCode' => '2-alphabet ISO-3166 code(eg.US,IN)',
        'mollieLocalhost' => 'The Mollie Webhook will work on a live server or with ngrok, but it will not function on localhost.',
        'alreadyRaisedRequest' => 'You have already raised a request.',
        'confirmRevert' => 'Yes, revert it!',
        'confirmNoArchive' => 'No, cancel please!',
        'sweetAlertTitle' => 'Are you sure?',
        'verify' => 'Verify',
        'reject' => 'Reject',
        'requestSuccessfullyVerified' => 'Request successfully verified',
        'requestSuccessfullyRejected' => 'Request successfully rejected',
        'confirmation' => [
            'recoverVerifiedRequest' => 'You will not be able to recover once verified this request',
            'recoverRejectedRequest' => 'You will not be able to recover once rejected this request',
        ],
        'offlineDescriptionPlaceholder' => 'Provide details of your offline payment'

    ],
    'accountSettings' => [
        'enableRegister' => 'Show signup button'
    ],
    'emailInfoCompany' => 'These login details will be used by the company admin to login to his company',
    'loginInfo' => 'You will be logout from Super Admin account. Click Login to proceed.',
    'successfullyLoginAsCompany' => 'Logged in as Company Successfully.',
    'stopImpersonation' => 'Stop Impersonation',
    'stopImpersonationTooltip' => 'Stop Impersonation and redirect back to superadmin panel',
    'impersonate' => 'You are now impersonating as',
    'loginWithDifferentEmail' => 'Login with a different email',
    'workspacesFor' => 'Workspaces for',
    'chooseWorkspace' => 'Choose a workspace below to get back to working with your team.',
    'main' => 'Main',
    'billedMonthly' => 'Billed Monthly',
    'billedAnnually' => 'Billed Annually',
    'pickUp' => 'Pick',
    'yourPlan' => ' Your Plan',
    'signUpThankYou' => 'Thank you for taking the time to sign up with us. We are excited to have you on board. Please wait while we prepare your account.',
    'signUpThankYouVerify' => 'Thank you for signing up. Please verify your email to get started',
    'dontHaveAccount' => 'Don\'t have an account yet?',
    'defaultLanguagePopover' => 'Select the default language of the front website that needs to be visible to the customers when the first lands up to the website',
    'showSignInPopover' => 'show sign in button on the front page',
    'showSignUpPopover' => 'show sign up button on the front page',
    'showGetStartedPopover' => 'show Get Started button on the front page',
    'goToWebsite' => 'Go to Home',

    'newCompany' => array(
        'subject' => 'New company registered',
        'text' => 'Great news! A new company has been successfully registered in our system. It\'s now ready to start using our services.',
    ),
    'themeSettings' => array(
        'adminPanelTheme' => 'Super Admin Panel Theme',
        'setThisCustomerTheme' => 'Set this theme for all customers',
        'setThisCustomerThemeInfo' => 'Customer will not be able to change the theme from admin panel',
    ),
    'frontDisableInfo' => 'Enabling it will disable the front website and will redirect to login page when any url from front website is opened',
    'featureImageSizeMessage' => 'Uploading image size should be 400x352.',
    'headerImageSizeMessage' => 'Uploading image size should be 688x504.',
    'unsubscribeSuccess' => 'Plan unsubscribe successfully.',
    'smtpConfigure' => 'Please configure the SMTP details to make emails work in the application.',
    'emailConfigure' => 'Choose from right sidebar all the emails notifications you want to receive.',
    'pushNotificationConfigure' => 'Choose from right sidebar all the push notifications you want to receive.',
    'loginRestricted' => 'You are not allowed to login in this organisation.',
    'companies' => [
        'unapproved' => 'Unapproved',
        'approvedChangedBy' => 'Approved Status Changed By',
        'companyNeedApproval' => 'Company approval is pending',
    ],
    'companyApproved' => array(
        'subject' => 'Your company account is approved.',
        'text' => 'We are pleased to inform you that your company account has been successfully approved and is now ready for use. You may now log in to start accessing our services.',
    ),
    'emailVerification' => 'Turn On Email Verification',
    'verifiedEmail' => 'Verified Email',
    'notVerifiedEmail' => 'Email not Verified',
    'emailVerificationEnableDisable' => 'Enable to force newly registered users for email verification. <br><br><p>An email will be send to their email address with verification link.</p>',
    'planPurchase' => array(
        'subject' => 'Plan Purchase',
        'text' => 'Company purchased plan',
    ),
    'cancelLicense' => array(
        'subject' => 'License cancelled due to failed payment.',
        'text' => 'License has been cancelled due to the failed payment. Please check the details.',
    ),
    'licenseExpirePre' => array(
        'subject' => 'Company license Expiring soon.',
        'text' => 'Your company license is expiring soon Please check your billing details.',
    ),
    'licenseExpire' => array(
        'subject' => 'Company Licence expired.',
        'text' => 'Your company license has been expired. Please check billing details.',
    ),
    'trialLicenseExpPre' => array(
        'subject' => 'Company trial package Expiring soon',
        'text' => 'Your company trial package is expiring soon Please check your billing details.',
    ),
    'trialLicenseExp' => array(
        'subject' => 'Company Trial package expired',
        'text' => 'Your company trial package has been expired and default package has been applied. Please check billing details soon.',
    ),
    'invoices' => array(
        'paymentReceived' => 'Payment received for invoice.',
        'offlinePaymentRequest' => 'Offline Payment Request.',
    ),
    'planUpdate' => array(
        'subject' => 'Company updated plan.',
        'text' => ':company has updated :package plan.',
    ),
    'signUpForCompany' => 'Sign up for :company',
    'clientRegistrationSuccess' => 'You have successfully registered.',
    'clientSignupUrl' => 'Client Signup URL',
    'clientSignupUrlNote' => 'This URL will be used by the client to register on the website.',
    'openInNewTab' => 'Open in new tab',
    'newSupportTicketRequester' => array(
        'subject' => 'New Support Ticket Has Been Generated For You.',
        'text' => 'New  ticket for support is has been generated for you. Login to view the ticket.',
    ),
    'newSupportTicket' => array(
        'subject' => 'New Ticket For Support Requested',
        'text' => 'A new support ticket has been created for you. Please log in to view the ticket details.',
        'notificationText' => 'New support ticket has been created for you.',
    ),
    'offlinePackageChangeRequest' => array(
        'subject' => ':company Request for modification of package',
        'text' => 'A request has been made to change the package in <b>:company</b>',
        'packageName' => 'Package Name',
    ),
    'theme1' => 'Theme 1',
    'theme2' => 'Theme 2',
    'companyApprovedSuccess' => 'Company Approved Successfully',
    'stripePackageMessage' => 'Once activated, you must include the ID of the Stripe product plan for each package.',
    'maxEmployeesLimitReached' => 'You have reached the maximum number of employees allowed in your plan. Please upgrade your plan to add more employees.',
    'verificationExpireIn' => 'Verification link will expire in :minutes minutes.',
    'razorpayPackageMessage' => 'Once activated, you must include the ID of the Razorpay product plan for each package.',
    'paystackPackageMessage' => 'Once activated, you must include the ID of the Paystack product plan for each package.',
    'payOnline' => 'Pay Online',
    'offlineUploadFile' => 'Please attach a file of your offline payment receipt',
    'offlinePackageRequestChange' => array(
        'subject' => 'Offline package change request',
        'text' => 'Your request has been :status for package of :package',
    ),
    'offlineRequestStatus' => array(
        'pending' => 'Pending',
        'verified' => 'Accepted',
        'rejected' => 'Declined',
    ),
    'offlineRequestStatusButton' => array(
        'pending' => 'Pending',
        'verified' => 'Accept',
        'rejected' => 'Decline',
    ),
    'offlinePlanChangeConfirm' => 'Are you sure you want to change the plan status?',
    'offlinePlanChangeRequestReceived' => 'Your request has been successfully submitted and is currently under review. We appreciate your patience as we process your request. Our team will notify you of any updates or further actions required. Thank you for choosing to work with us.',
    'footerSettingPageType' => 'Private page can be use in other page as link. A Private page will not displayed in header or footer.',
    'externalLink' => 'External link will treat as a link and open in new page.',
    'footerPagePosition' => 'Page link position',
    'selfTickets' => 'Self Tickets',
    'cannotUseEmail' => 'Company Already exists with similar email id. Please use different email account',
    'registerMessage' => 'This message will show on registration page when registration will close.',
    'footerScriptMessage' => 'The following script, if any, will be inserted before &#60;/body&#62; tag.',
    'headerScriptMessage' => ' The following script, if any, will be inserted into the &#60;head&#62; section.',
    'supportTicketReply' => array(
        'subject' => 'Support Ticket Reply',
        'text' => 'New reply received on support ticket ',
        'action' => 'View Ticket',
    ),
    'offlineRequestChange' => array(
        'remarkRequired' => 'Remark is required',
        'paymentDateRequired' => 'Payment date is required',
        'nextPaymentDateRequired' => 'Next payment date is required',
    ),
    'subscriptionDate' => 'Subscription Date',
    'paymentFailed' => 'Payment Failed',
    'myAccount' => 'My Account',
    'contactSupport' => 'Contact Support',
    'myTickets' => 'My Tickets',
    'theme2Login' => "<strong>Theme 2</strong> has 2 login view options",
    'primaryColorTooltip' => 'The color will be displayed on the front-end website theme, including buttons, icons, and other elements.',
    'VisitFrontWebsite' => 'Visit Front Website',
    'cannotDeleteFirstSuperadmin' => 'You cannot delete the first superadmin.',
    'emailAlreadyExist' => 'The email has already been taken.',
    'previousPassword' => 'Same as previous password.',
    'slug' => 'Slug',
    'googleCalendarConfig' => 'Choose from right sidebar all the Google Calendar settings.',
    'subdomainNotAdded' => 'subdomain not added',
    'planUpgradeNotOnMobile' => 'Plan upgrade not available on mobile device. Please upgrade your plan on desktop device.',
    'signUpApprovalPending' => 'Thank you for taking the time to sign up with us. We are excited to have you on board. Your company is not approved yet!. Please wait for the company approval.',
    'clientSignUpApprovalPending' => 'Thank you for taking the time to sign up with us. We are excited to have you on board. Your are not approved yet!. Please wait for the approval',
    'clientSignUpApprovalMailVerificationPending' => 'Please verify your email to complete the setup process.',
    'approvalPending' => 'Thank you for taking the time to sign up with us. We are excited to have you on board. Your\'s company and you both are not approved yet!. Please wait for the approval or click to ',
    'clientSignUpApprovedMailVerificationPending' => 'Your account has been approved. Please verify your email to complete the setup process.',
    // 'approval' => 'Please verify your email.',
    'approval' => 'Your company has been successfully verified! Please verify your email to complete the setup process.',
    'emailVerificationCode' => array(
        'text' => 'Congratulations! Your account has been created successfully. You can login now and start using our service.',
        'action' => 'Email Verify',
        'line1' => 'Your email verification code is ',
        'line2' => 'The code will expire in 30 minutes. Didn’t try to sign up? You can safely ignore this email.',
        'verifiedSuccess' => 'Email verification successfull.',
        'verifyCode' => 'Verify Code',
        'resendVerifyCode' => 'Resend Verification Code',
        'enterVerificationCode' => 'Enter verification code',
        'newEmailCodeSent' => 'A new email verification code has been emailed to you!',
        'enterVerificationCodeEmail' => 'Enter the verification code sent on your email.',
    ),
    'emailVerify' => array(
        'subject' => 'Email Verification',
        'text' => 'Thank you for registration. Here are your email verification instructions. A request to your email verification has been made. If you did not make this request, simply ignore this email. If you did make this request, please verify ',
    ),
    'superadminRoleAndPermission' => 'Superadmin Role & Permission',
    'roleSweetAlertTitle' => 'Can\'t Delete',
    'roleSweetAlertMessage' => 'Users have this role. remove their role first.',
    'roleNotFound' => 'Roles not found. Please add roles',
    'roleAlreadyExist' => 'Roles name already exist',
    'recaptchaInvalid' => 'Google recaptcha invalid',
    'ogImage' => 'Og image',
    'issueWithCompany' => 'Issue with your company',
    'issueWithCompanyText' => 'Please notify your company admin to resolve the issue.',
    'packageIssueNotified' => 'You have been notified about the issue to your company admin.',
    'issueNotifyButton' => 'Notify Admin',
    'packageEmployeeIssueEmail' => array(
        'subject' => 'Issue with your company',
        'text' => 'Your users :userName is facing issue with your company. Please resolve the issue.',
    ),
    'youCanNotSignUp' => 'You can not sign up. Please contact your company admin.',
    'trialPackageSettings' => 'Trial Package Settings',
    'superadminPermissionsCantChange' => 'Superadmin permissions can not be changed.',
    'updatePlanNote' => 'The limit for your employee package has been exceeded. To address this, you have two options: either disable some employees or update your package to accommodate a higher limit.',
    'ok' => 'Ok',
    'modules' => array(
        'packages' => 'Packages',
        'companies' => 'Companies',
        'billing' => 'Billing',
        'offlinerequest' => 'Offline Request',
        'admin_faq' => 'Admin FAQ',
        'superadmin' => 'Superadmin',
        'superadmin_ticket' => 'Superadmin Ticket',
        'superadmin_settings' => 'Superadmin Settings',
        'affiliate' => 'Affiliates',
    ),
    'companyCurrentPackage' => 'Company\'s Current Package',
    'noActivePackage' => 'No active package found',
    'emailCantUse' => 'This email can not be used.',
    'addCompany' => 'Add Company',
    'addPackage' => 'Add Package',
    'addSuperAdmin' => 'Add Super Admin',
    'addAdminFaq' => 'Add Admin FAQ',
    'offlineRequest' => 'Offline Request',
    'emailCannotChange' => 'Email can not be changed. Email can be change from profile settings.',
    'subDomainNotUpdated' => 'Please update subdomain module to latest version.',
    'contactUsMessage' => 'Thanks for contacting us. We will catch you soon.',
    'registeredHeaders' => 'Registered Company Details',
    'registeredIp' => 'Registered From IP',
    'validationSubDomain' => 'The Subdomain field must start with an letter and can contain only letters , numbers, underscores, and hyphens',
    'userAgent' => 'Browser Info',
    'browserDetectDescription' => 'Here are the details of the registered company. You\'ll find information about the browser and desktop used during company registration. This helps detect bots and shows which browsers companies use most for registration.',
    'browserDetectTooltip' => [
        'userAgent' => 'Current visitor\'s HTTP_USER_AGENT string',
        'isMobile' => 'Registered from a mobile device?',
        'isTablet' => 'Registered from a tablet device?',
        'isDesktop' => 'Registered from a desktop device?',
        'isBot' => 'Registered from a crawler / bot?',
        'deviceType' => 'Enumerated response for [Mobile, Tablet, Desktop, and Bot]',
        'browserName' => 'Browser\'s human friendly name like Firefox 3.6, Chrome 42',
        'browserFamily' => 'Browser\'s vendor like Chrome, Firefox, Opera',
        'browserVersion' => 'Browser\'s human friendly version string.',
        'browserVersionMajor' => 'Browser\'s semantic major version.',
        'browserVersionMinor' => 'Browser\'s semantic minor version.',
        'browserVersionPatch' => 'Browser\'s semantic patch version.',
        'browserEngine' => 'Browser\'s engine like: Blink, WebKit, Gecko.',
        'isWindows' => 'Registered from a Windows operating system?',
        'isLinux' => 'Registered from a Linux based operating system?',
        'isMac' => 'Registered from an iOS or Mac based operating system.',
        'isAndroid' => 'Registered from an Android operating system?',
        'deviceFamily' => 'Device\'s vendor like Samsung, Apple, Huawei?',
        'deviceModel' => 'Device\'s brand name like iPad, iPhone, Nexus?',
        'isChrome' => 'Registered from a Chrome browser?',
        'isFirefox' => 'Registered from a Firefox browser?',
        'isOpera' => 'Registered from an Opera browser?',
        'isSafari' => 'Registered from a Safari browser?',
        'isIE' => 'Checks if the browser is some kind of Internet Explorer (or Trident).',
        'isIEVersion' => 'Compares to a given IE version',
        'isEdge' => 'Registered from a Microsoft Edge browser?',
        'isInApp' => 'Check for browsers rendered inside applications like Android WebView.',
        'platformName' => "Operating system's human-friendly name like Windows XP, Mac 10.",
        'platformFamily' => "Operating system's vendor like Linux, Windows, Mac.",
        'platformVersion' => "Operating system's human-friendly version like XP, Vista, 10.",
        'platformVersionMajor' => "Operating system's semantic major version.",
        'platformVersionMinor' => "Operating system's semantic minor version.",
        'platformVersionPatch' => "Operating system's semantic patch version."
    ],
    'billing_name' => 'Billing Name',
    'billing_address' => 'Billing Address',
    'billing_tax_name' => 'TAX name',
    'billing_tax_id' => 'Tax ID'

];
