<?php

return array (
    'manage_skill' => 'Manage Skills',
    'add_job' => 'Add Job',
    'view_job' => 'View Job',
    'edit_job' => 'Edit Job',
    'delete_job' => 'Delete Job',
    'add_job_application' => 'Add Job Application',
    'view_job_application' => 'View Job Application',
    'edit_job_application' => 'Edit Job Application',
    'delete_job_application' => 'Delete Job Application',
    'add_notes' => 'Add Notes',
    'edit_notes' => 'Edit Notes',
    'delete_notes' => 'Delete Notes',
    'add_application_status' => 'Add Application Status',
    'edit_application_status' => 'Edit Application Status',
    'delete_application_status' => 'Delete Application Status',
    'change_application_status' => 'Change Application Status',
    'add_interview_schedule' => 'Add Interview Schedule',
    'view_interview_schedule' => 'View Interview Schedule',
    'edit_interview_schedule' => 'Edit Interview Schedule',
    'delete_interview_schedule' => 'Delete Interview Schedule',
    'reschedule_interview' => 'Reschedule Interview',
    'add_recommendation_status' => 'Add Recommendation Status',
    'edit_recommendation_status' => 'Edit Recommendation Status',
    'delete_recommendation_status' => 'Delete Recommendation Status',
    'add_recruiter' => 'Add Recruiter',
    'edit_recruiter' => 'Edit Recruiter',
    'delete_recruiter' => 'Delete Recruiter',
    'add_offer_letter' => 'Add Offer Letter',
    'view_offer_letter' => 'View Offer Letter',
    'edit_offer_letter' => 'Edit Offer Letter',
    'delete_offer_letter' => 'Delete Offer Letter',
    'add_footer_link' => 'Add Footer Link',
    'edit_footer_link' => 'Edit Footer Link',
    'delete_footer_link' => 'Delete Footer Link',
    'view_report' => 'View Report',
    'recruit_settings' => 'Recruit Settings',
    'manage_salary_payment_method' => 'Manage Salary Payment Method',
    'manage_salary_component' => 'Manage Salary Component',
    'manage_salary_group' => 'Manage Salary Group',
    'manage_salary_tds' => 'Manage Salary Tds',
    'manage_employee_salary' => 'Manage Employee Salary',
    'add_payroll' => 'Add Payroll',
    'view_payroll' => 'View Payroll',
    'edit_payroll' => 'Edit Payroll',
    'delete_payroll' => 'Delete Payroll',
    'manage_job_category' => 'Manage Job Category',
    'manage_job_sub_category' => 'Manage Job Sub Category',
    'add_clients' => 'Add Clients',
    'view_clients' => 'View Clients',
    'edit_clients' => 'Edit Clients',
    'delete_clients' => 'Delete Clients',
    'manage_client_category' => 'Manage Client Category',
    'manage_client_subcategory' => 'Manage Client Subcategory',
    'add_client_contacts' => 'Add Client Contacts',
    'view_client_contacts' => 'View Client Contacts',
    'edit_client_contacts' => 'Edit Client Contacts',
    'delete_client_contacts' => 'Delete Client Contacts',
    'add_client_note' => 'Add Client Note',
    'view_client_note' => 'View Client Note',
    'edit_client_note' => 'Edit Client Note',
    'delete_client_note' => 'Delete Client Note',
    'add_client_document' => 'Add Client Document',
    'view_client_document' => 'View Client Document',
    'edit_client_document' => 'Edit Client Document',
    'delete_client_document' => 'Delete Client Document',
    'add_employees' => 'Add Employees',
    'view_employees' => 'View Employees',
    'edit_employees' => 'Edit Employees',
    'delete_employees' => 'Delete Employees',
    'add_designation' => 'Add Designation',
    'view_designation' => 'View Designation',
    'edit_designation' => 'Edit Designation',
    'delete_designation' => 'Delete Designation',
    'add_department' => 'Add Department',
    'view_department' => 'View Department',
    'edit_department' => 'Edit Department',
    'delete_department' => 'Delete Department',
    'add_documents' => 'Add Documents',
    'view_documents' => 'View Documents',
    'edit_documents' => 'Edit Documents',
    'delete_documents' => 'Delete Documents',
    'view_leaves_taken' => 'View Leaves Taken',
    'update_leaves_quota' => 'Update Leaves Quota',
    'view_employee_tasks' => 'View Employee Tasks',
    'view_employee_projects' => 'View Employee Projects',
    'view_employee_timelogs' => 'View Employee Timelogs',
    'change_employee_role' => 'Change Employee Role',
    'manage_emergency_contact' => 'Manage Emergency Contact',
    'manage_award' => 'Manage Award',
    'add_appreciation' => 'Add Appreciation',
    'view_appreciation' => 'View Appreciation',
    'edit_appreciation' => 'Edit Appreciation',
    'delete_appreciation' => 'Delete Appreciation',
    'add_immigration' => 'Add Immigration',
    'view_immigration' => 'View Immigration',
    'edit_immigration' => 'Edit Immigration',
    'delete_immigration' => 'Delete Immigration',
    'add_projects' => 'Add Projects',
    'view_projects' => 'View Projects',
    'edit_projects' => 'Edit Projects',
    'delete_projects' => 'Delete Projects',
    'manage_project_category' => 'Manage Project Category',
    'view_project_files' => 'View Project Files',
    'add_project_files' => 'Add Project Files',
    'delete_project_files' => 'Delete Project Files',
    'view_project_discussions' => 'View Project Discussions',
    'add_project_discussions' => 'Add Project Discussions',
    'edit_project_discussions' => 'Edit Project Discussions',
    'delete_project_discussions' => 'Delete Project Discussions',
    'manage_discussion_category' => 'Manage Discussion Category',
    'view_project_milestones' => 'View Project Milestones',
    'add_project_milestones' => 'Add Project Milestones',
    'edit_project_milestones' => 'Edit Project Milestones',
    'delete_project_milestones' => 'Delete Project Milestones',
    'view_project_members' => 'View Project Members',
    'add_project_members' => 'Add Project Members',
    'edit_project_members' => 'Edit Project Members',
    'delete_project_members' => 'Delete Project Members',
    'view_project_rating' => 'View Project Rating',
    'add_project_rating' => 'Add Project Rating',
    'edit_project_rating' => 'Edit Project Rating',
    'delete_project_rating' => 'Delete Project Rating',
    'view_project_budget' => 'View Project Budget',
    'view_project_timelogs' => 'View Project Timelogs',
    'view_project_expenses' => 'View Project Expenses',
    'view_project_tasks' => 'View Project Tasks',
    'view_project_invoices' => 'View Project Invoices',
    'view_project_orders' => 'View Project Orders',
    'view_project_burndown_chart' => 'View Project Burndown Chart',
    'view_project_payments' => 'View Project Payments',
    'view_project_gantt_chart' => 'View Project Gantt Chart',
    'add_project_note' => 'Add Project Note',
    'view_project_note' => 'View Project Note',
    'edit_project_note' => 'Edit Project Note',
    'delete_project_note' => 'Delete Project Note',
    'manage_project_template' => 'Manage Project Template',
    'view_project_template' => 'View Project Template',
    'view_project_hourly_rates' => 'View Project Hourly Rates',
    'create_public_project' => 'Create Public Project',
    'view_miroboard' => 'View Miroboard',
    'manage_employee_shifts' => 'Manage Employee Shifts',
    'view_shift_roster' => 'View Shift Roster',
    'add_attendance' => 'Add Attendance',
    'view_attendance' => 'View Attendance',
    'edit_attendance' => 'Edit Attendance',
    'delete_attendance' => 'Delete Attendance',
    'add_tasks' => 'Add Tasks',
    'view_tasks' => 'View Tasks',
    'edit_tasks' => 'Edit Tasks',
    'delete_tasks' => 'Delete Tasks',
    'view_task_category' => 'View Task Category',
    'add_task_category' => 'Add Task Category',
    'edit_task_category' => 'Edit Task Category',
    'delete_task_category' => 'Delete Task Category',
    'view_task_files' => 'View Task Files',
    'add_task_files' => 'Add Task Files',
    'delete_task_files' => 'Delete Task Files',
    'view_sub_tasks' => 'View Sub Tasks',
    'add_sub_tasks' => 'Add Sub Tasks',
    'edit_sub_tasks' => 'Edit Sub Tasks',
    'delete_sub_tasks' => 'Delete Sub Tasks',
    'view_task_comments' => 'View Task Comments',
    'add_task_comments' => 'Add Task Comments',
    'edit_task_comments' => 'Edit Task Comments',
    'delete_task_comments' => 'Delete Task Comments',
    'view_task_notes' => 'View Task Notes',
    'add_task_notes' => 'Add Task Notes',
    'edit_task_notes' => 'Edit Task Notes',
    'delete_task_notes' => 'Delete Task Notes',
    'task_labels' => 'Task Labels',
    'change_status' => 'Change Status',
    'send_reminder' => 'Send Reminder',
    'add_status' => 'Add Status',
    'view_unassigned_tasks' => 'View Unassigned Tasks',
    'create_unassigned_tasks' => 'Create Unassigned Tasks',
    'add_estimates' => 'Add Estimates',
    'view_estimates' => 'View Estimates',
    'edit_estimates' => 'Edit Estimates',
    'delete_estimates' => 'Delete Estimates',
    'add_invoices' => 'Add Invoices',
    'view_invoices' => 'View Invoices',
    'edit_invoices' => 'Edit Invoices',
    'delete_invoices' => 'Delete Invoices',
    'manage_tax' => 'Manage Tax',
    'link_invoice_bank_account' => 'Link Invoice Bank Account',
    'manage_recurring_invoice' => 'Manage Recurring Invoice',
    'add_payments' => 'Add Payments',
    'view_payments' => 'View Payments',
    'edit_payments' => 'Edit Payments',
    'delete_payments' => 'Delete Payments',
    'link_payment_bank_account' => 'Link Payment Bank Account',
    'add_timelogs' => 'Add Timelogs',
    'view_timelogs' => 'View Timelogs',
    'edit_timelogs' => 'Edit Timelogs',
    'delete_timelogs' => 'Delete Timelogs',
    'approve_timelogs' => 'Approve Timelogs',
    'manage_active_timelogs' => 'Manage Active Timelogs',
    'view_timelog_earnings' => 'View Timelog Earnings',
    'add_tickets' => 'Add Tickets',
    'view_tickets' => 'View Tickets',
    'edit_tickets' => 'Edit Tickets',
    'delete_tickets' => 'Delete Tickets',
    'manage_ticket_type' => 'Manage Ticket Type',
    'manage_ticket_agent' => 'Manage Ticket Agent',
    'manage_ticket_channel' => 'Manage Ticket Channel',
    'manage_ticket_tags' => 'Manage Ticket Tags',
    'add_events' => 'Add Events',
    'view_events' => 'View Events',
    'edit_events' => 'Edit Events',
    'delete_events' => 'Delete Events',
    'add_notice' => 'Add Notice',
    'view_notice' => 'View Notice',
    'edit_notice' => 'Edit Notice',
    'delete_notice' => 'Delete Notice',
    'add_leave' => 'Add Leave',
    'view_leave' => 'View Leave',
    'edit_leave' => 'Edit Leave',
    'delete_leave' => 'Delete Leave',
    'approve_or_reject_leaves' => 'Approve Or Reject Leaves',
    'delete_approve_leaves' => 'Delete Approve Leaves',
    'add_lead' => 'Add Lead',
    'view_lead' => 'View Lead',
    'edit_lead' => 'Edit Lead',
    'delete_lead' => 'Delete Lead',
    'view_lead_agents' => 'View Deal Agents',
    'add_lead_agent' => 'Add Deal Agent',
    'edit_lead_agent' => 'Edit Deal Agent',
    'delete_lead_agent' => 'Delete Deal Agent',
    'view_lead_category' => 'View Deal Category',
    'add_lead_category' => 'Add Deal Category',
    'edit_lead_category' => 'Edit Deal Category',
    'delete_lead_category' => 'Delete Deal Category',
    'manage_lead_custom_forms' => 'Manage Lead Custom Forms',
    'view_lead_files' => 'View Deal Files',
    'add_lead_files' => 'Add Deal Files',
    'delete_lead_files' => 'Delete Deal Files',
    'view_lead_follow_up' => 'View Deal Follow Up',
    'add_lead_follow_up' => 'Add Deal Follow Up',
    'edit_lead_follow_up' => 'Edit Deal Follow Up',
    'delete_lead_follow_up' => 'Delete Deal Follow Up',
    'view_lead_sources' => 'View Lead Sources',
    'add_lead_sources' => 'Add Lead Sources',
    'edit_lead_sources' => 'Edit Lead Sources',
    'delete_lead_sources' => 'Delete Lead Sources',
    'view_lead_proposals' => 'View Deal Proposals',
    'add_lead_proposals' => 'Add Deal Proposals',
    'edit_lead_proposals' => 'Edit Deal Proposals',
    'delete_lead_proposals' => 'Delete Deal Proposals',
    'manage_proposal_template' => 'Manage Proposal Template',
    'change_lead_status' => 'Change Lead Status',
    'add_lead_note' => 'Add Lead Note',
    'view_lead_note' => 'View Lead Note',
    'edit_lead_note' => 'Edit Lead Note',
    'delete_lead_note' => 'Delete Lead Note',
    'manage_lead_status' => 'Manage Lead Status',
    'add_holiday' => 'Add Holiday',
    'view_holiday' => 'View Holiday',
    'edit_holiday' => 'Edit Holiday',
    'delete_holiday' => 'Delete Holiday',
    'add_product' => 'Add Product',
    'view_product' => 'View Product',
    'edit_product' => 'Edit Product',
    'delete_product' => 'Delete Product',
    'manage_product_category' => 'Manage Product Category',
    'manage_product_sub_category' => 'Manage Product Sub Category',
    'add_expenses' => 'Add Expenses',
    'view_expenses' => 'View Expenses',
    'edit_expenses' => 'Edit Expenses',
    'delete_expenses' => 'Delete Expenses',
    'manage_expense_category' => 'Manage Expense Category',
    'manage_recurring_expense' => 'Manage Recurring Expense',
    'approve_expenses' => 'Approve Expenses',
    'link_expense_bank_account' => 'Link Expense Bank Account',
    'add_contract' => 'Add Contract',
    'view_contract' => 'View Contract',
    'edit_contract' => 'Edit Contract',
    'delete_contract' => 'Delete Contract',
    'manage_contract_type' => 'Manage Contract Type',
    'renew_contract' => 'Renew Contract',
    'add_contract_discussion' => 'Add Contract Discussion',
    'edit_contract_discussion' => 'Edit Contract Discussion',
    'view_contract_discussion' => 'View Contract Discussion',
    'delete_contract_discussion' => 'Delete Contract Discussion',
    'add_contract_files' => 'Add Contract Files',
    'view_contract_files' => 'View Contract Files',
    'delete_contract_files' => 'Delete Contract Files',
    'manage_contract_template' => 'Manage Contract Template',
    'view_task_report' => 'View Task Report',
    'view_time_log_report' => 'View Time Log Report',
    'view_finance_report' => 'View Finance Report',
    'view_income_expense_report' => 'View Income Vs Expense Report',
    'view_leave_report' => 'View Leave Report',
    'view_attendance_report' => 'View Attendance Report',
    'view_expense_report' => 'View Expense Report',
    'manage_company_setting' => 'Manage Company Setting',
    'manage_app_setting' => 'Manage App Setting',
    'manage_notification_setting' => 'Manage Notification Setting',
    'manage_currency_setting' => 'Manage Currency Setting',
    'manage_payment_setting' => 'Manage Payment Setting',
    'manage_finance_setting' => 'Manage Finance Setting',
    'manage_ticket_setting' => 'Manage Ticket Setting',
    'manage_project_setting' => 'Manage Project Setting',
    'manage_attendance_setting' => 'Manage Attendance Setting',
    'manage_leave_setting' => 'Manage Leave Setting',
    'manage_custom_field_setting' => 'Manage Custom Field Setting',
    'manage_message_setting' => 'Manage Message Setting',
    'manage_storage_setting' => 'Manage Storage Setting',
    'manage_language_setting' => 'Manage Language Setting',
    'manage_lead_setting' => 'Manage Lead Setting',
    'manage_time_log_setting' => 'Manage Time Log Setting',
    'manage_task_setting' => 'Manage Task Setting',
    'manage_social_login_setting' => 'Manage Social Login Setting',
    'manage_security_setting' => 'Manage Security Setting',
    'manage_gdpr_setting' => 'Manage Gdpr Setting',
    'manage_theme_setting' => 'Manage Theme Setting',
    'manage_role_permission_setting' => 'Manage Role Permission Setting',
    'manage_module_setting' => 'Manage Module Setting',
    'manage_google_calendar_setting' => 'Manage Google Calendar Setting',
    'view_overview_dashboard' => 'View Overview Dashboard',
    'view_project_dashboard' => 'View Project Dashboard',
    'view_client_dashboard' => 'View Client Dashboard',
    'view_hr_dashboard' => 'View Hr Dashboard',
    'view_ticket_dashboard' => 'View Ticket Dashboard',
    'view_finance_dashboard' => 'View Finance Dashboard',
    'add_order' => 'Add Order',
    'view_order' => 'View Order',
    'edit_order' => 'Edit Order',
    'delete_order' => 'Delete Order',
    'add_knowledgebase' => 'Add Knowledgebase',
    'view_knowledgebase' => 'View Knowledgebase',
    'edit_knowledgebase' => 'Edit Knowledgebase',
    'delete_knowledgebase' => 'Delete Knowledgebase',
    'add_bankaccount' => 'Add Bankaccount',
    'view_bankaccount' => 'View Bankaccount',
    'edit_bankaccount' => 'Edit Bankaccount',
    'delete_bankaccount' => 'Delete Bankaccount',
    'add_bank_transfer' => 'Add Bank Transfer',
    'add_bank_deposit' => 'Add Bank Deposit',
    'add_bank_withdraw' => 'Add Bank Withdraw',
    'view_lead_report' => 'View Lead Report',
    'manage_ticket_groups' => 'Manage Ticket Groups',
    'add_asset' => 'Add Asset',
    'view_asset' => 'View Asset',
    'edit_asset' => 'Edit Asset',
    'delete_asset' => 'Delete Asset',
    'add_zoom_meetings' => 'Add Meetings',
    'view_zoom_meetings' => 'View Meetings',
    'edit_zoom_meetings' => 'Edit Meetings',
    'delete_zoom_meetings' => 'Delete Meetings',
    'add_assets_type' => 'Add Assets Type',
    'edit_assets_type' => 'Edit Assets Type',
    'view_assets_type' => 'View Assets Type',
    'delete_assets_type' => 'Delete Assets Type',
    'edit_assets_history' => 'Edit Assets History',
    'delete_assets_history' => 'Delete Assets History',
    'view_assets_history' => 'View Assets History',
    'manage_zoom_category' => 'Manage Zoom category',
    'manage_test_push_notification' => 'Manage Test Push Notification',
    'manage_rest_api_settings' => 'Manage Rest Api Settings',
    'manage_sms_settings' => 'Manage Sms Settings',
    'manage_contract_setting' => 'Manage Contract Setting',
    'manage_custom_link_setting' => 'Manage Custom Link Setting',
    'view_sales_report' => 'View Sales Report',
    'view_webhooks_logs' => 'View Webhooks Logs',
    'add_letter' => 'Add Letter',
    'edit_letter' => 'Edit Letter',
    'delete_letter' => 'Delete Letter',
    'view_letter' => 'View Letter',
    'add_vendor' => 'Add Vendor',
    'view_vendor' => 'View Vendor',
    'edit_vendor' => 'Edit Vendor',
    'delete_vendor' => 'Delete Vendor',
    'manage_vendor_contact' => 'Manage Vendor Contact',
    'manage_vendor_note' => 'Manage Vendor Note',
    'add_purchase_order' => 'Add Purchase Order',
    'view_purchase_order' => 'View Purchase Order',
    'edit_purchase_order' => 'Edit Purchase Order',
    'delete_purchase_order' => 'Delete Purchase Order',
    'add_bill' => 'Add Bill',
    'is_custom' => 1,
    'view_bill' => 'View Bill',
    'edit_bill' => 'Edit Bill',
    'delete_bill' => 'Delete Bill',
    'add_vendor_payment' => 'Add Vendor Payment',
    'view_vendor_payment' => 'View Vendor Payment',
    'edit_vendor_payment' => 'Edit Vendor Payment',
    'delete_vendor_payment' => 'Delete Vendor Payment',
    'add_vendor_credit' => 'Add Vendor Credit',
    'view_vendor_credit' => 'View Vendor Credit',
    'edit_vendor_credit' => 'Edit Vendor Credit',
    'delete_vendor_credit' => 'Delete Vendor Credit',
    'add_inventory' => 'Add Inventory',
    'view_inventory' => 'View Inventory',
    'edit_inventory' => 'Edit Inventory',
    'delete_inventory' => 'Delete Inventory',
    'manage_stock_adjustment' => 'Manage Stock Adjustment',
    'manage_inventory_adjustment' => 'Manage Inventory Adjustment',
    'view_order_report' => 'View Order Report',
    'view_vendor_report' => 'View Vendor Report',
    'link_order_bank_account' => 'Link Order Bank Account',
    'view_inventory_valuation_summary' => 'View Inventory Valuation Summary',
    'view_inventory_summary' => 'View Inventory Summary',
    'view_purchase_setting' => 'View Purchase Setting',
    'manage_deal_stages' => 'Manage Deal Stages',
    'change_deal_stages' => 'Change Deal Stages',
    'add_deals' => 'Add Deals',
    'view_deals' => 'View Deals',
    'edit_deals' => 'Edit Deals',
    'delete_deals' => 'Delete Deals',
    'add_deal_pipeline' => 'Add Deal pipeline',
    'view_deal_pipeline' => 'View Deal pipeline',
    'edit_deal_pipeline' => 'Edit Deal pipeline',
    'delete_deal_pipeline' => 'Delete Deal pipeline',
    'add_deal_note' => 'Add Deal Note',
    'view_deal_note' => 'View Deal Note',
    'edit_deal_note' => 'Edit Deal Note',
    'delete_deal_note' => 'Delete Deal Note',
    'add_template' => 'Add Template',
    'view_template' => 'View Template',
    'edit_template' => 'Edit Template',
    'delete_template' => 'Delete Template',
    'add_estimate_request' => 'Add Estimate Request',
    'view_estimate_request' => 'View Estimate Request',
    'edit_estimate_request' => 'Edit Estimate Request',
    'delete_estimate_request' => 'Delete Estimate Request',
    'reject_estimate_request' => 'Reject Estimate Request',
    'view_increment_promotion' => 'View Increment & Promotion',
    'manage_increment_promotion' => 'Manage Increment & Promotion',
    'manage_performance_setting' => 'Manage Performance Setting',
    'manage_biometric_settings' => 'Manage Biometric Settings',

    'manage_billing' => 'Manage Billing',
    'view_request' => 'View Request',
    'accept_reject_request' => 'Accept And Reject Request',
    'manage_faq_category' => 'Manage Faq Category',
    'manage_superadmin_front_settings' => 'Manage Front Settings',
    'manage_superadmin_app_settings' => 'Manage App Settings',
    'manage_superadmin_notification_settings' => 'Manage Notification Settings',
    'manage_superadmin_language_settings' => 'Manage Language Settings',
    'manage_superadmin_currency_settings' => 'Manage Currency Settings',
    'manage_superadmin_payment_settings' => 'Manage Payment Credentials Settings',
    'manage_superadmin_finance_settings' => 'Manage Finance Settings',
    'manage_superadmin_custom_field_settings' => 'Manage Custom Field Settings',
    'manage_superadmin_permission_settings' => 'Manage Permission Settings',
    'manage_superadmin_storage_settings' => 'Manage Storage Settings',
    'manage_superadmin_social_settings' => 'Manage Social Settings',
    'manage_superadmin_security_settings' => 'Manage Security Settings',
    'manage_superadmin_theme_settings' => 'Manage Theme Settings',
    'manage_superadmin_custom_module_settings' => 'Manage Custom Module Settings',
    'manage_superadmin_database_backup_settings' => 'Manage Database Backup Settings',
    'manage_superadmin_update_settings' => 'Manage Update App Settings',
    'manage_superadmin_calendar_settings' => 'Manage Calendar Settings',
    'change_superadmin_role' => 'Change Superadmin Role',
    'update_company_package' => 'Update Company Package',
    'manage_company_impersonate' => 'Manage Company Impersonate',
    'add_affiliates' => 'Add Affiliates',
    'view_affiliates' => 'View Affiliates',
    'edit_affiliates' => 'Edit Affiliates',
    'manage_affiliate_status' => 'Manage Affiliate Status',
    'delete_affiliates' => 'Delete Affiliates',
    'manage_affiliate_settings' => 'Manage Affiliate Settings',
    'view_affiliate_dashboard' => 'View Affiliate Dashboard',
    'add_referrals' => 'Add Referrals',
    'view_referrals' => 'View Referrals',
    'add_payouts' => 'Add Payouts',
    'view_payouts' => 'View Payouts',
    'edit_payouts' => 'Edit Payouts',
    'delete_payouts' => 'Delete Payouts',
    'manage_payout_status' => 'Manage Payout Status',
);
