<?php

return [
    'fromNumber' => 'From',
    'notificationTitle' => 'Set Notification Settings',
    'notificationSubtitle' => 'Select the events for which a message should be sent',
    'smsSetting' => 'SMS Setting',
    'msg91FlowId' => 'Msg91 Flow ID',
    'whatsappTemplateId' => 'Whatsapp Template SID',
];
