<?php
return [
    'saveSettings' => 'Save settings',
    'cookiePreferences' => 'Cookie preferences',
    'title' => 'We use cookies!',
    'description' => 'Hi, this website uses essential cookies to ensure its proper operation and tracking cookies to understand how you interact with it. The latter will be set only after consent. ',
    'letMeChoose' => 'Let me choose',
    'acceptAll' => 'Accept all',
    'rejectAll' => 'Reject all',
    'acceptNecessary' => 'Accept Necessary',
    'cookieUsage' => 'Cookie usage',
    'cookieUsageDescription' => 'I use cookies to ensure the basic functionalities of the website and to enhance your online experience. You can choose for each category to opt-in/out whenever you want. For more details relative to cookies and other sensitive data.',
    'strictlyNecessaryCookies' => 'Strictly necessary cookies',
    'strictlyNecessaryCookiesDescription' => 'These cookies are essential for the proper functioning of my website. Without these cookies, the website would not work properly',
    'performanceAnalyticsCookies' => 'Performance and Analytics cookies',
    'performanceAnalyticsCookiesDescription' => 'These cookies allow the website to remember the choices you have made in the past',
    'moreInformation' => 'More information',
    'moreInformationDescription' => 'For any queries in relation to our policy on cookies and your choices, please',
    'advertisementTitle' => 'Advertisement and Targeting cookies',
    'advertisementTitleDescription' => 'These cookies collect information about how you use the website, which pages you visited and which links you clicked on. All of the data is anonymized and cannot be used to identify you',
];

