<?php

return array(
    'newEvent' => array(
        'subject' => 'New Event Created',
        'text' => 'We are excited to announce a new event that has been created and we would like to invite you to join us. To make it easier for you to save the date, we have attached an ICS file to this email that you can download and add to your calendar.',
        'hostText' => 'I am writing to confirm that you have been selected as the host for :eventName. Your enthusiasm and dedication to our :companyName make you an ideal candidate for this role, and we are confident that you will represent us admirably.',
        'statusSubject' => 'Event Status Update',
        'eventCancelNote' => 'We are very sorry to announce that due to some reason event has been cancelled. ',
        'action' => 'View Event',
        'mentionSubject' => 'You have been mentioned in a event',
    ),
    'loginDashboard' => 'Go To Dashboard',
    'viewInvoice' => 'View Invoice',
    'thankyouNote' => 'Thank you for using our application!',
    'notificationAction' => 'Notification Action',
    'notificationIntro' => 'The introduction to the notification.',
    'hello' => 'Hello',
    'whoops' => 'Whoops',
    'regards' => 'Regards',
    'newExpense' => array(
        'subject' => 'New Expense Submitted for Approval',
        'newSubject' => 'New Expense has been Submitted',
        'action' => 'View Expense',
    ),
    'newExpenseRecurring' => array(
        'subject' => 'New Recurring Expense Submitted for Approval',
        'action' => 'View Recurring Expense',
    ),
    'expenseStatus' => array(
        'subject' => 'Expense status updated',
        'text' => 'Your expense status updated to',
        'action' => 'View Expense',
    ),
    'expenseRecurringStatus' => array(
        'subject' => 'Recurring Expense status updated',
        'text' => 'Your Recurring expense status updated to',
        'action' => 'View Recurring Expense',
    ),
    'newNotice' => array(
        'subject' => 'Important Notice: New Update Published',
        'text' => 'New notice has been published. Login to view the notice.',
        'action' => 'View Notice',
    ),
    'newProjectMember' => array(
        'subject' => 'Project Update: You have been assigned a new project',
        'text' => 'Exciting news! You\'ve been assigned a new project.',
        'text2' => 'To get started, log in to your account and check out the project details.',
        'action' => 'View Project',
        'mentionProject' => 'You Have Been Mention On New Project',
        'mentionText' => 'You have been mentioned on project',
        'mentionProjectNote' => 'Project Update: You Have Been Mention On New Project Note',
        'mentionNoteText' => 'You have been mentioned on project Note',
    ),
    'projectNote' => array(
            'mentionSubject' => 'You have Been Mention On New Project Note',
            'mentionText' => 'You have been mentioned on New Project Note',
            'text' => 'New note added for',
            'action' => 'View Note',
            'subject' => 'New note added for Project',
    ),
    'newProject' => array(
        'subject' => 'New Project Added',
        'text' => 'A new project added with the name',
        'withName' => 'with name.',
        'loginNow' => ' Login now to view the project.',
    ),
    'newProjectStatus' => array(
        'subject' => 'Project Status Updated',
        'text' => 'Project Status has been changed',
        'withName' => 'with name.',
        'loginNow' => ' Login now to view the project.',
    ),

    'newTask' => array(
        'subject' => 'Task Assignment: A New Task has been Assigned to You',
        'text' => 'We hope you\'re having a great day! You have been assigned a new task.',
        'mentionSubject' => 'You\'ve Been Mentioned in a Task!',
        'mentionTask' => 'Heads up! You\'ve been mentioned in a task.',

    ),
    'dueOn' => 'Due On',
    'newTicket' => array(
        'subject' => 'New Support Ticket Requested',
        'text' => 'New Support Ticket is requested. Login to view the ticket.',
        'action' => 'View Ticket',
    ),
    'newUser' => array(
        'subject' => 'Welcome to',
        'text' => 'Congratulations! Your account has been created successfully. You can login now and start using our service.',
        'message' => 'Congratulations! Your account has been created successfully.',
        'clientSignupMessage' => 'Congratulations! Your account has been approved successfully.',
        'action' => 'Login to Dashboard',
    ),
    'newUserViaLink' => array(
        'subject' => 'New Team Member: Welcome to the Team!',
        'text' => 'New account has been created successfully via an invitation link. Following are the details-',
        'action' => 'View User Details',
    ),
    'leaves' => array(
        'subject' => 'New leave request received',
        'statusSubject' => 'Leave application status updated',
        'multipleSubject' => 'New multiple leave request received by :user',
        'action' => 'View Leave',
    ),
    'taskComplete' => array(
        'subject' => 'Task marked as complete',
        'action' => 'View Task',
        'completedBy' => 'Task completed by',
    ),
    'taskUpdate' => array(
        'subject' => 'Your Task Has Been Updated!',
        'text' => 'Just a quick heads-up! A task assigned to you has been updated.',
        'text2' => 'To check out the changes and keep things moving, log in to your account and head over to the Task section.',
        'action' => 'View Task',
        'updatedBy' => 'Task Status Updated By',
        'statusUpdated' => 'Your Task Status Has Been Updated!',
        'slackStatusUpdated' => 'The following task has been updated, Assigned Employees please check the task for updates!'
    ),
    'taskApproval' => array(
        'subject' => 'Task sent for the approval.',
        'text' => 'Task sent for the approval.',
        'action' => 'View Task',
        'updatedBy' => 'Updated By',
    ),
    'leave' => array(
        'approve' => 'Leave application approved.',
        'reject' => 'Leave application rejected.',
        'applied' => 'Leave application applied.',
        'action' => 'View Leave Application',
    ),
    'newClientTask' => array(
        'subject' => 'New Task Generated',
        'content' => 'A New Task has been Created in Project',
    ),
    'reminder' => array(
        'subject' => 'Reminder for assigned task',
    ),
    'invoices' => array(
        'paymentReceived' => 'Payment Received: Confirmation',
        'paymentReceivedForInvoice' => 'Payment received for invoice ',
        'paymentReceivedForOrder' => 'Payment received for order ',
        'action' => 'View Invoice',
        'newPaymentReceived' => 'New Payment Received',
        'paymentReminder' => 'Payment Reminder Received',
    ),
    'orders' => array(
        'action' => 'View Order',
        'subject' => 'New Order Recieved',

    ),
    'eventReminder' => array(
        'subject' => 'Reminder: Upcoming Event - Save the Date!',
        'text' => 'This is to remind you about the following event. Log in for more details about the event.',
        'action' => 'View Event',
    ),
    'taskReminder' => array(
        'subject' => 'Urgent Task Reminder: Deadline Approaching',
    ),
    'estimate' => array(
        'subject' => 'New Estimate Created',
        'text' => 'A new estimate has been created. Please click on the link below to view the estimate.',
        'loginDashboard' => 'Approve / Reject',
    ),
    'invoice' => array(
        'subject' => 'New Invoice Received',
        'text' => 'We\'re excited to inform you that a new invoice has been received. To review the details of the invoice, please click on the link provided below:<br>',
        'action' => 'View Invoice',
        'updateSubject' => 'Invoice Updated',
        'updateText' => 'Invoice has been updated. Please click on the link below to view invoice.',
        'updateTextSms' => 'Invoice has been updated. Please check the invoice :invoice_number.',
    ),
    'order' => array(
        'subject' => 'New Order Placed',
        'text' => 'A new order has been placed. Please click on the link below to view the order.',
        'action' => 'View Order',
        'updateSubject' => 'Order Updated',
        'updateText' => 'Order has been updated. Please click on the link below to view the order.',
    ),
    'projectReminder' => array(
        'text' => 'This is to remind you about the due date of the following projects which is',
        'subject' => 'Project Reminder',
        'action' => 'View Projects',
    ),
    'messages' => array(
        'loginForMoreDetails' => 'Log in for more details.',
        'referenceMessage' => 'I have attached a copy of the invoice for your reference.',
        'confirmMessage' => 'I would be grateful if you could confirm that everything is on track for payment.'
    ),
    'taskComment' => array(
        'subject' => 'New comment on task',
        'action' => 'View Task Comment',
        'mentionTask' => 'You have been mentioned in a task comment',
        'mentionSubject' => 'Mentioned On Comment',
        'commentedBy' => 'Commented by',
    ),
    'taskNote' => array(
        'subject' => 'New note added for task',
        'action' => 'View Task Note',
        'mentionNote' => 'You have been mention in task note',
        'mentionSubject' => 'Mentioned On Note',
    ),
    'removalRequestAdmin' => array(
        'subject' => 'New Removal Request',
        'text' => 'New removal request has been received',
    ),
    'removalRequestApprovedUser' => array(
        'subject' => 'Removal Request Approval',
        'text' => 'Your removal request has been approved',
    ),
    'removalRequestRejectedUser' => array(
        'subject' => 'Removal Request Rejected',
        'text' => 'Your removal request has been rejected',
    ),
    'removalRequestApprovedLead' => array(
        'subject' => 'Removal Request Approval',
        'text' => 'Your removal request for lead has been approved',
    ),
    'removalRequestRejectedLead' => array(
        'subject' => 'Removal Request Rejected',
        'text' => 'Your removal request for lead has been rejected',
    ),
    'paymentReminder' => array(
        'subject' => 'Payment Reminder',
        'content' => 'This is to remind you about the due date of the following project invoice payment which is',
        'smsText' => 'This is to remind you about the due date of the following project invoice payment :invoice_number which is :due_date.',
    ),
    'fileUpload' => array(
        'subject' => 'New file uploaded to project : ',
        'action' => 'View Project Files',
    ),
    'payment' => array(
        'subject' => 'Payment Received!',
        'text' => 'A new Payment has been done. Login now to view the Payment.',
        'action' => 'View Payment',
        'amount' => 'Paid Amount',
        'method' => 'Payment mode',
        'invoiceNumber' => 'Invoice Number',
        'clientsubject' => 'Payment Success',
        'clientName' => 'Client Name',
        'clientEmail' => 'Client Email',
        'Project' => 'Project',
    ),
    'ticketAgent' => array(
        'subject' => 'You have been assigned a ticket',
        'text' => 'You have been assigned a new ticket.',
        'action' => 'View Ticket',
        'mentionSubject' => 'You have been mentioned in a ticket',
        'mentionedText' => 'You have been mentioned in a new ticket',
    ),
    'subTaskComplete' => array(
        'subject' => 'Sub Task marked as complete',
        'action' => 'View Sub Tasks',
    ),
    'subTaskAssigneeAdded' => array(
        'subject' => 'Sub Task assigned to you.',
        'text' => 'You have been added as assignee on Task ',
        'action' => 'View Sub Tasks',
    ),

    'leadAgent' => array(
        'subject' => 'New Deal Notification',
        'action' => 'View Deal',
        'viewMore' => 'View More',
    ),

    'lead' => array(
        'subject' => 'New lead received.',
        'action' => 'View Lead',
    ),

    'leads' => array(
        'subject' => 'New leads received.',
        'action' => 'View Lead',
    ),

    'dealStatus' => array(
        'subject' => 'Deal stage updated.',
        'action' => 'View Deal',
    ),

    'subTaskCreated' => 'Sub task created.',
    'discussionReply' => array(
        'subject' => ' replied to ',
        'text' => 'You have received a reply on ',
        'action' => 'View Discussion',
    ),
    'discussion' => array(
        'subject' => 'New discussion started ',
        'action' => 'View Discussion',
        'mentionSubject' => 'Mentioned On Discussion',
        'mentionContent' => 'You have been mentioned on new Project Discussion',
    ),
    'ticketReply' => array(
        'receivedNote' => 'added a note and wants you to have a look.',
        'subject' => 'New ticket reply received',
        'receivedText' => 'You have received a reply on ticket ',
        'repliedText' => 'You have replied on ticket ',
        'action' => 'View Ticket',
        'text' => 'You have received a reply on ticket ',
        'noteAdded' => 'Note Added',
    ),
    'contractSign' => array(
        'subject' => 'Contract Signed',
        'text' => ':contract (contract) is signed by :client.',
    ),
    'newContract' => array(
        'subject' => 'New Contract Created!',
        'text' => 'A new contract has been created.',
    ),
    'newChat' => array(
        'subject' => 'New message received',
        'action' => 'View Message',
        'mentionSubject' => 'Mentioned On Message',
        'mentionContent' => 'You have been mentioned On message',
    ),
    'noticeUpdate' => array(
        'subject' => 'A notice has been updated',
        'text' => 'Notice has been updated. Login to view the notice.',
        'action' => 'View Notice',
    ),
    'payments' => array(
        'paymentReceived' => 'Payment Received',
    ),
    'estimateDeclined' => array(
        'subject' => 'Estimate Declined',
        'text' => 'A estimate has been Declined. Please click on the link below to check the estimate.',
        'smsText' => 'A estimate has been Declined. Kindly check the estimate #:estimate_number',
        'action' => 'View Estimate',
    ),
    'estimateAccepted' => array(
        'subject' => 'Estimate Accepted',
    ),
    'newMeeting' => array(
        'subject' => 'New Meeting Created',
        'text' => 'New meeting has been created. Download the attachment to add meeting to your calendar.',
    ),
    'removalRequestApproved' => array(
        'subject' => 'Removal Request Approval',
        'text' => 'Your removal request for lead has been Approved',
    ),
    'removalRequestReject' => array(
        'subject' => 'Removal Request Reject',
        'text' => 'Your removal request for lead has been rejected',
    ),
    'newTicketRequester' => array(
        'subject' => 'New Ticket Has Been Generated For You.',
        'text' => 'New support ticket is has been generated for you. Login to view the ticket.',
        'action' => 'View Ticket',
    ),
    'newInvoiceRecurring' => array(
        'subject' => 'New Recurring Invoice submitted',
        'text' => 'A new recurring invoice has been submitted. Please click on the link below to view the invoice.',
        'smsText' => 'A new recurring invoice has been submitted.',
        'action' => 'View Recurring Invoice',
    ),
    'invoiceRecurringStatus' => array(
        'subject' => 'Recurring Invoice status updated',
        'text' => 'Your recurring invoice status updated to',
        'action' => 'View Recurring Invoice',
    ),
    'creditNote' => array(
        'subject' => 'New Credit Note received',
        'text' => 'A new credit note has been received. Login now to view the credit note.',
        'action' => 'View Credit Note',
    ),
    'proposal' => array(
        'subject' => 'New Proposal Received',
        'text' => 'A new proposal has been received. Login now to view the proposal.',
    ),
    'proposalSigned' => array(
        'subject' => 'Proposal has been accepted!',
        'text' => 'A new Proposal has been accepted and signed.',
        'approve' => 'Approved By',
    ),
    'proposalRejected' => array(
        'subject' => 'Proposal has been declined by lead!',
        'text' => 'A new Proposal has been declined.',
        'rejected' => 'Rejected',
    ),
    'testMail' => array(
        'testMail' => 'Test Mail',
        'mailAddress' => 'Enter the email address where test mail needs to be sent',
    ),
    'invitation' => array(
        'subject' => ' has invited you to join ',
        'action' => 'Accept Invitation',
    ),
    'invoiceReminder' => array(
        'subject' => 'Invoice Reminder',
        'text' => 'This is to remind you about the due date of the following invoice which is',
        'action' => 'View Invoice',
    ),
    'invoiceReminderAfter' => array(
        'subject' => 'Invoice Reminder',
        'text' => 'I just wanted to drop you a quick note to remind you that the due for payment on',
        'action' => 'View Invoice',
    ),
    'test' => array(
        'subject' => 'Confirm Receipt: Test Email',
        'text' => 'This is a test email to verify that the SMTP settings are configured correctly and the email system is functioning properly. If you receive this message, it means that the SMTP configuration is working fine.',
        'slack'=>'This is a test notification',
        'thankyouNote' => 'Thank you for using our application!',
    ),
    'AttendanceReminder' => array(
        'subject' => 'Action Required: Mark Today\'s Attendance',
        'text' => 'This email is a friendly reminder to mark your attendance for today. We noticed that you have not yet clocked in and we wanted to remind you to do so as soon as possible to avoid being marked as absent.',
        'action' => 'Mark Attendance',
    ),
    'BirthdayReminder' => array(
        'subject' => 'members have a birthday today',
        'text' => 'The following team members are celebrating their birthdays today',
        'action' => 'Go to dashboard',
        'birthdayNotification' => 'have birthday',
        'birthdayNotificationText' => ' others have a birthday on ',
    ),
    'twoFactor' => array(
        'line1' => 'Your two-factor authentication code is ',
        'line2' => 'The code will expire in 10 minutes',
        'line3' => 'If you have not tried to login, ignore this message.',
    ),
    'newCustomer' => array(
        'subject' => 'New Customer Registration',
        'text' => 'New customer has been registered.'
    ),
    'footer' => 'If you\'re experiencing difficulties with clicking the ":actionText" button, kindly copy and paste the URL below into your web browser:',
    'productPurchase' => array(
        'subject' => 'New Product Purchase',
        'text' => 'A new product purchase has been made. Login now to view the purchase.',
        'action' => 'View Invoice',
    ),
    'followUpReminder' => array(
        'subject' => 'Urgent: Follow-up Reminder',
        'newFollowUpSubject' => 'New Follow-up Created ',
        'nextFollowUpDate' => 'Next follow up date',
        'action' => 'View Follow Up Details',
        'nextFollowUpTime' => 'Next follow up time',
        'followUpLead' => 'Followup Deal Name',
        'followUpLeadText' => 'You have new follow up',
    ),
    'shiftScheduled' => array(
        'subject' => 'Schedule Update: Your Shifts have been Assigned'
    ),
    'shiftChange' => array(
        'subject' => 'New Shift Change Request Received',
        'action' => 'Go to Shift Roster',
        'text' => 'Request to change Shift is received.'
    ),
    'shiftChangeStatus' => array(
        'subject' => 'Shift change request response',
        'text' => 'Your request for shift change is '
    ),
    'newAppreciation' => array(
        'subject' => 'Congratulations: You Have Been Awarded',
        'text' => 'You have been awarded :award on :award_at',
        'action' => 'View Award Details',
    ),
    'attendanceReport' => array(
        'subject' => 'Attendance Report for the month of ',
        'text' => 'Please find the attendance report in attachment.'
    ),
    'trackerReminder' => array(
        'subject' => 'Time Tracker Reminder',
        'text' => 'You forgot to start the time tracker.',
        'action' => 'View Tasks',
        'dear' => 'Dear',
    ),
    'holidays' => array(
        'subject' => 'New Holiday Created',
        'text' => 'Created a new holiday.',
        'action' => 'View Holiday',
    ),
    'dailyTimelogReport' => array(
        'subject' => 'Timelog Report for the date',
        'text' => 'Please find the timelog report in attachment.'
    ),
    'rating' => array(
        'subject' => 'Rating added on project',
        'text' => 'Rating added on project-.',
     ),
     'forgetPassword' => array(
        'subject' => 'Reset Password Notification',
        'content' => 'You are receiving this email because we received a password reset request for your account.',
        'actionButton' => 'Reset Password',
        'expire' => 'This password reset link will expire in 60 minutes.',
        'contentPassword' => 'If you did not request a password reset, no further action is required.',
     ),
     'projectRating' => [
        'subject' => 'New project rating',
        'action' => 'Show Rating',
        'text' => 'New project rating received for the project '
     ],
     'dailyScheduleReminder' => [
        'subject' => 'Your Daily Focus List for :date',
        'content' => "Here's your daily focus list for today. We've curated these tasks to help you stay organized and productive throughout the day:",
        'taskText' => 'Total Tasks',
        'eventText' => 'Total Events',
        'holidayText' => 'Total Holiday',
        'leavesText' => 'Total Leaves',
        'interviewText' => 'Total Interview'
     ],
    'estimateRequestRejected' => array(
        'subject' => 'Estimate Request Rejected',
        'text' => 'A estimate request has been Rejected. Please click on the link below to check the estimate request.',
        'action' => 'View Estimate Request',
    ),
    'estimate_request_invite' => array(
        'subject' => 'Estimate Request Invite',
        'text' => 'You have been invited to create the estimate request. Please click on the link below to create the estimate request.',
        'action' => 'Create Estimate Request',
        'content' => 'You have been invited to create the estimate request. Please click on the link below to create the estimate request.',
    ),
    'estimateRequestAccepted' => array(
        'subject' => 'Estimate Request Accepted',
        'text' => 'A estimate request has been Accepted. Please click on the link below to check the estimate request.',
    ),
    'newEstimateRequest' => array(
        'subject' => 'New Estimate Request',
        'text' => 'A new estimate request has been created. Please click on the link below to view the estimate request.',
    ),
    'incrementPromotion' => array(
        'in' => 'in',
        'same' => 'same',
        'subject' => 'Cheers to Your New Role',
        'text' => 'I\'m excited to announce your well-deserved promotion to',
        'text1' => 'Your exceptional contributions and commitment have not gone unnoticed. We can\'t wait to see the great things you\'ll accomplish in this new role.',
        'text2' => 'If you need any support during your transition, just let us know. Congratulations again!',
        'text3' => 'You have promoted to position',
        'updateText' => 'I am excited to announce changes to your recent promotion',
    ),
    'newTimesheetApproval' => array(
        'subject' => 'New Timesheet Submitted by :employeeName',
        'greeting' => 'New Timesheet Submitted',
        'text' => 'A new timesheet has been submitted for approval.',
        'text1' => 'Timesheet for the week of :startDate to :endDate by :employeeName',
        'action' => 'View Timesheet',
        'thankYou' => 'Thank you for using our application!',
    ),
    'weeklyTimesheetApproved' => array(
        'subject' => 'Weekly Timesheet Approved',
        'greeting' => 'Weekly Timesheet Approved',
        'text' => 'A weekly timesheet has been approved.',
        'text1' => 'Timesheet for the week of :startDate to :endDate by :employeeName',
        'action' => 'View Timesheet',
        'thankYou' => 'Thank you for using our application!',
    ),
    'weeklyTimesheetRejected' => array(
        'subject' => 'Weekly Timesheet Rejected',
        'greeting' => 'Weekly Timesheet Rejected',
        'text' => 'A weekly timesheet has been rejected.',
        'text1' => 'Timesheet for the week of :startDate to :endDate',
        'text2' => 'Reason: :reason',
        'action' => 'View Timesheet',
        'thankYou' => 'Thank you for using our application!',
    ),
);
