<?php

return [
    'newTask' => 'New Task assigned to you',
    'newClientTask' => 'New Task Created',
    'sendTestMessage' => 'Send Test Message',
    'gatewayLimitation' => 'Only 1 gateway can be enabled at a time',
    'noGatewayEnabled' => 'You will have to enable a Gateway to send message.',
    'incorrectNumber' => 'Mobile number is not correct',
    'mobileNumberFormat' => 'Make sure you have set the correct mobile number with country code for the users',
    'telegramUserId' => 'Telegram User ID',
    'userIdInfo' => 'Send a message to <strong>@userinfobot</strong> from your telegram account to get your Telegram user ID',
    'testSmsNotificationDisabled' => 'Test SMS Notification is disabled please enable it from SMS Settings',
    'telegramTelegramBotToken' => 'Telegram Bot Token',
    'telegramTelegramBotName' => 'Telegram Bot Name',
    'telegramBotNameInfo' => 'Note: You need to start chat on below bot link on your telegram account.',
    'smsConfigure' => 'Choose from right sidebar all the sms notifications you want to receive.'
];
