<?php

return [
    'attendance-reminder' => 'You forgot to mark your today attendance. Kindly clock-in to avoid being marked as absent.',
    'follow-up-reminder' => 'Follow Up Reminder for Lead # :leadId. Next Follow Up Date : :followUpDate. Remark : :remark',
    'auto-task-reminder' => 'Auto Task Reminder for Task # :taskId. Task Heading : :heading. Due Date : :dueDate',
    'contract-signed' => 'Contract Signed for Contract # :contract by :client.',
    'estimate-declined' => 'Estimate has been declined. Kindly check the estimate # :estimateNumber.',
    'event-invite' => 'Event Invitation.' . "\n" . 'Event Name : :eventName. Event Start Date : :eventStartDate.' . "\n" . 'Event End Date : :eventEndDate.' . "\n" . 'Event Venue : :eventLocation',
    'event-reminder' => 'Event Reminder.' . "\n" . 'Event Name : :eventName. Event Start Date : :eventStartDate.' . "\n" . 'Event End Date : :eventEndDate.' . "\n" . 'Event Venue : :eventLocation',
    'recurring-expense-status-updated' => 'Recurring Expense Status Updated.' . "\n" . 'Expense Name : :expenseName. Expense Status : :expenseStatus.',
    'new-file-uploaded-to-project' => 'New file uploaded to Project # :projectName.' . "\n" . 'File Name : :fileName' . "\n" . 'Date : :date',
    'payment-received' => 'This is a confirmation message for :paymentType payment # :number',
    'payment-reminder' => 'This is to remind you about the due date of the following project invoice payment :invoiceNumber which is :dueDate',
    'project-reminder' => 'This is to remind you about the due date of the following projects which is :dueDate',
    'proposal-approved' => 'Proposal has been accepted!' . "\n" . 'A new Proposal has been accepted and signed.' . "\n" . 'Approved By : :name.' . "\n" . 'Proposal Status : :status.',
    'proposal-rejected' => 'Proposal has been declined by lead!' . "\n" . 'A new Proposal has been declined.' . "\n" . 'Rejected : :comment.' . "\n" . 'Proposal Status : :status.',
    'recurring-invoice-status-updated' => 'Your recurring invoice status updated to :status.',
    'invoice-reminder' => 'Invoice Reminder - :invoiceNumber' . "\n" . 'This is to remind you about the due date of the following invoice which is :dueDate.',
    'new-expense-added-by-admin' => 'New Expense submitted by :name. Expense details: :itemName - :price',
    'new-expense-added-by-member' => 'New Expense submitted. Expense details: :itemName - :price',
    'invoice-created' => 'New Invoice Received - Invoice No. is :invoiceNumber',
    'invoice-updated' => 'Invoice has been updated. Please check the invoice :invoiceNumber',
    'lead-notification' => 'New Lead Received. Lead Details: :leadName',
    'new-leave-application' => 'A Leave application applied.' . "\n" . 'On Date: :leaveDate',
    'new-leave-request' => 'New leave request received by :name.' . "\n" . 'On Date: :leaveDate' . "\n" . 'Reason: :reason',
    'leave-approved' => 'A Leave application approved.' . "\n" . 'On Date: :leaveDate',
    'leave-rejected' => 'A Leave application rejected.' . "\n" . 'On Date: :leaveDate',
    'leave-updated' => 'A Leave application status updated.' . "\n" . 'Status: :status',
    'multiple-leave-application' => 'Multiple leave application received by :name.' . "\n" . 'Reason: :reason',
    'new-multiple-leave-application' => 'New multiple leave application received by :name.' . "\n" . 'Reason: :reason' . "\n" . 'Leave Type: :leaveType',
    'new-task' => 'New Task Assigned to You.' . "\n" . 'Task Details: :heading' . "\n" . 'Task ID: :taskId' . "\n" . 'Due Date: :dueDate',
    'new-order' => 'New Order Received.' . "\n" . 'Order Number: :orderNumber' . "\n" . 'Login now to view the order.',
    'order-updated' => 'Order Updated.' . "\n" . 'Order Number: :orderNumber' . "\n" . 'Login now to view the order.',
    'new-payment' => 'Payment Received!' . "\n" . 'A new Payment has been done. Login now to view the Payment.',
    'new-product-purchase' => 'New Product Purchase' . "\n" . 'A new product purchase has been made. Login now to view the purchase.',
    'new-project' => 'New Project Added' . "\n" . 'A new project added with name - :projectName. Login now to view the project.',
    'new-proposal' => 'New Proposal Received' . "\n" . 'A new proposal has been received. Login now to view the proposal.',
    'new-recurring-invoice' => 'A new recurring invoice has been submitted.',
    'new-ticket-reply' => 'New ticket reply received' . "\n" . 'You have received a reply on Ticket :ticketNumber',
    'new-ticket-request' => 'New support ticket is has been generated for you. Login to view the ticket.',
    'task-updated' => 'Task updated' . "\n" . 'Task Details: :heading' . "\n" . 'Task ID: :taskId' . "\n" . 'Due Date: :dueDate',
    'task-completed-client' => 'Task marked as completed.' . "\n" . 'Task Details: :heading' . "\n" . 'Task ID: :taskId',
    'task-completed' => 'Task marked as completed.' . "\n" . 'Task Details: :heading' . "\n" . 'Task ID: :taskId' . "\n" . 'Project: :project',
    'new-client-task' => 'New Task Generated - Task Heading is :heading',
    'task-update-client' => 'Task updated' . "\n" . 'Task Details: :heading' . "\n" . 'Task ID: :taskId',
    'new-notice-published' => 'New Notice Published - Notice is: :heading',
    'new-support-ticket-request' => 'New Support Ticket Requested' . "\n" . 'Ticket ID: :ticketId' . "\n" . 'Ticket Subject: :subject' . "\n" . 'Ticket Requested By: :ticketRequesterName',
    'agent-ticket' => 'You have been assigned a ticket' . "\n" . 'Ticket ID: :ticketId' . "\n" . 'Ticket Subject: :subject',
    'employee-assign-to-project' => 'New Project Assigned' . "\n" . 'You have been added as a member to the project - :projectName',
    'user-join-via-invitation' => 'New user joined via link.' . "\n" . 'New account has been created successfully via invitation link. Following are the details-' . "\n" . 'Name: :name' . "\n" . 'Email: :email' . "\n" . 'Phone: :phone',
    'notice-updated' => 'Notice has been updated. Login to view the notice.' . "\n" . 'Notice Heading: :heading',
    'removal-request-admin-notification' => 'New removal request has been received',
    'removal-request-approved' => 'Your removal request has been approved',
    'removal-request-reject' => 'Your removal request has been rejected',
    'removal-request-approved-lead' => 'Your removal request for lead has been approved',
    'removal-request-reject-lead' => 'Your removal request for lead has been rejected',
    'sub-task-assignee-added' => 'Sub Task assigned to you.' . "\n" . 'Task Details: :title' . "\n" . 'Project: :project',
    'sub-task-completed' => 'Sub Task marked as completed.' . "\n" . 'Task Details: :title' . "\n" . 'Project: :project',
    'task-comment' => 'New comment on task.' . "\n" . 'Task Details: :heading' . "\n" . 'Task ID: :taskId' . "\n" . 'Project: :project',
    'task-note' => 'New note added for task - :heading' . "\n" . 'Task ID: :taskId' . "\n" . 'Project: :project',
    'task-reminder' => 'Reminder for assigned task - :heading' . "\n" . 'Task ID: :taskId' . "\n" . 'Date: :date',
    'user-registrationadded-by-admin' => 'New user added.' . "\n" . 'New account has been created successfully via invitation link. Following are the details-' . "\n" . 'Name: :name' . "\n" . 'Email: :email' . "\n" . 'Password: :password',
    'test-sms-notification' => 'This is :gateway test message',
    'two-factor-code' => 'Your two factor code is :code' . "\n" . 'This code will expire in 10 minutes.' . "\n" . 'If you have not tried to login, ignore this message.',
    'removal-request-reject-user' => 'Removal Request Rejected' . "\n" . 'Your removal request has been rejected',
    'removal-request-approved-user' => 'Removal Request Approval' . "\n" . 'Your removal request has been approved',
];
