<?php

return array(
    'accepted' => 'The :attribute must be accepted.',
    'active_url' => 'The :attribute is not a valid URL.',
    'after' => 'The :attribute must be a date after :date.',
    'after_or_equal' => 'The :attribute must be a date after or equal to :date.',
    'alpha' => 'The :attribute may only contain letters.',
    'alpha_dash' => 'The :attribute may only contain letters, numbers, and dashes.',
    'alpha_num' => 'The :attribute may only contain letters and numbers.',
    'array' => 'The :attribute must be an array.',
    'before' => 'The :attribute must be a date before :date.',
    'before_or_equal' => 'The :attribute must be a date before or equal to :date.',
    'accepted_if' => 'The :attribute field must be accepted when :other is :value.',
    'ascii' => 'The :attribute field must only contain single-byte alphanumeric characters and symbols.',
    'between' => array(
        'numeric' => 'The :attribute must be between :min and :max.',
        'file' => 'The :attribute must be between :min and :max kilobytes.',
        'string' => 'The :attribute must be between :min and :max characters.',
        'array' => 'The :attribute must have between :min and :max items.',
    ),
    'boolean' => 'The :attribute field must be true or false.',
    'confirmed' => 'The :attribute confirmation does not match.',
    'date' => 'The :attribute is not a valid date.',
    'date_format' => 'The :attribute does not match the format :format.',
    'different' => 'The :attribute and :other must be different.',
    'digits' => 'The :attribute must be :digits digits.',
    'digits_between' => 'The :attribute must be between :min and :max digits.',
    'dimensions' => 'The :attribute has invalid image dimensions.',
    'distinct' => 'The :attribute field has a duplicate value.',
    'email' => 'The :attribute must be a valid email address.',
    'invalidEmail' => 'Please enter a valid email address.',
    'invalidEmailPassword' => 'Email and password combination is not correct.',
    'exists' => 'The selected :attribute is invalid.',
    'file' => 'The :attribute must be a file.',
    'filled' => 'The :attribute field must have a value.',
    'image' => 'The :attribute must be an image.',
    'in' => 'The selected :attribute is invalid.',
    'in_array' => 'The :attribute field does not exist in :other.',
    'integer' => 'The :attribute must be an integer.',
    'ip' => 'The :attribute must be a valid IP address.',
    'json' => 'The :attribute must be a valid JSON string.',

    'current_password' => 'The password is incorrect.',
    'date_equals' => 'The :attribute field must be a date equal to :date.',
    'decimal' => 'The :attribute field must have :decimal decimal places.',
    'declined' => 'The :attribute field must be declined.',
    'declined_if' => 'The :attribute field must be declined when :other is :value.',
    'doesnt_end_with' => 'The :attribute field must not end with one of the following: :values.',
    'doesnt_start_with' => 'The :attribute field must not start with one of the following: :values.',
    'ends_with' => 'The :attribute field must end with one of the following: :values.',
    'enum' => 'The selected :attribute is invalid.',
    'gt' => [
        'array' => 'The :attribute field must have more than :value items.',
        'file' => 'The :attribute field must be greater than :value kilobytes.',
        'numeric' => 'The :attribute field must be greater than :value.',
        'string' => 'The :attribute field must be greater than :value characters.',
    ],
    'gte' => [
        'array' => 'The :attribute field must have :value items or more.',
        'file' => 'The :attribute field must be greater than or equal to :value kilobytes.',
        'numeric' => 'The :attribute field must be greater than or equal to :value.',
        'string' => 'The :attribute field must be greater than or equal to :value characters.',
    ],
    'ipv4' => 'The :attribute field must be a valid IPv4 address.',
    'ipv6' => 'The :attribute field must be a valid IPv6 address.',
    'lowercase' => 'The :attribute field must be lowercase.',
    'lt' => [
        'array' => 'The :attribute field must have less than :value items.',
        'file' => 'The :attribute field must be less than :value kilobytes.',
        'numeric' => 'The :attribute field must be less than :value.',
        'string' => 'The :attribute field must be less than :value characters.',
    ],
    'lte' => [
        'array' => 'The :attribute field must not have more than :value items.',
        'file' => 'The :attribute field must be less than or equal to :value kilobytes.',
        'numeric' => 'The :attribute field must be less than or equal to :value.',
        'string' => 'The :attribute field must be less than or equal to :value characters.',
    ],
    'mac_address' => 'The :attribute field must be a valid MAC address.',
    'max' => array(
        'numeric' => 'The :attribute may not be greater than :max.',
        'file' => 'The :attribute may not be greater than :max kilobytes.',
        'string' => 'The :attribute may not be greater than :max characters.',
        'array' => 'The :attribute may not have more than :max items.',
    ),
    'max_digits' => 'The :attribute field must not have more than :max digits.',
    'mimes' => 'The :attribute must be a file of type: :values.',
    'mimetypes' => 'The :attribute must be a file of type: :values.',
    'min' => array(
        'numeric' => 'The :attribute must be at least :min.',
        'file' => 'The :attribute must be at least :min kilobytes.',
        'string' => 'The :attribute must be at least :min characters.',
        'array' => 'The :attribute must have at least :min items.',
    ),
    'not_in' => 'The selected :attribute is invalid.',
    'numeric' => 'The :attribute must be a number.',
    'present' => 'The :attribute field must be present.',
    'regex' => 'The :attribute format is invalid.',
    'required' => 'The :attribute field is required.',
    'required_if' => 'The :attribute field is required when :other is :value.',
    'required_unless' => 'The :attribute field is required unless :other is in :values.',
    'required_with' => 'The :attribute field is required when :values is present.',
    'required_with_all' => 'The :attribute field is required when :values is present.',
    'required_without' => 'The :attribute field is required when :values is not present.',
    'required_without_all' => 'The :attribute field is required when none of :values are present.',
    'same' => 'The :attribute and :other must match.',
    'min_digits' => 'The :attribute field must have at least :min digits.',
    'missing' => 'The :attribute field must be missing.',
    'missing_if' => 'The :attribute field must be missing when :other is :value.',
    'missing_unless' => 'The :attribute field must be missing unless :other is :value.',
    'missing_with' => 'The :attribute field must be missing when :values is present.',
    'missing_with_all' => 'The :attribute field must be missing when :values are present.',
    'multiple_of' => 'The :attribute field must be a multiple of :value.',
    'not_regex' => 'The :attribute field format is invalid.',
    'password' => [
        'letters' => 'The :attribute field must contain at least one letter.',
        'mixed' => 'The :attribute field must contain at least one uppercase and one lowercase letter.',
        'numbers' => 'The :attribute field must contain at least one number.',
        'symbols' => 'The :attribute field must contain at least one symbol.',
        'uncompromised' => 'The given :attribute has appeared in a data leak. Please choose a different :attribute.',
    ],
    'prohibited' => 'The :attribute field is prohibited.',
    'prohibited_if' => 'The :attribute field is prohibited when :other is :value.',
    'prohibited_unless' => 'The :attribute field is prohibited unless :other is in :values.',
    'prohibits' => 'The :attribute field prohibits :other from being present.',
    'required_array_keys' => 'The :attribute field must contain entries for: :values.',
    'required_if_accepted' => 'The :attribute field is required when :other is accepted.',
    'size' => array(
        'numeric' => 'The :attribute must be :size.',
        'file' => 'The :attribute must be :size kilobytes.',
        'string' => 'The :attribute must be :size characters.',
        'array' => 'The :attribute must contain :size items.',
    ),
    'string' => 'The :attribute must be a string.',
    'timezone' => 'The :attribute must be a valid zone.',
    'unique' => 'The :attribute has already been taken.',
    'uploaded' => 'The :attribute failed to upload.',
    'url' => 'The :attribute format is invalid.',
    'email_domain' => 'The :attribute must be a valid domain e.g. gmail.com',
    'slack_webhook' => 'The webhook format is invalid. For more information please visit this',
    'not_custom_fields' => 'You can not add the custom field with this label because you cannnot use same label name for same module',
    'starts_with' => 'The :attribute field must start with one of the following: :values.',
    'ulid' => 'The :attribute field must be a valid ULID.',
    'uppercase' => 'The :attribute field must be uppercase.',
    'uuid' => 'The :attribute field must be a valid UUID.',
    'custom' => array(
        'attribute-name' => array(
            'rule-name' => 'custom-message',
        ),
    ),
    'givenDataInvalid' => 'The given data was invalid.',

    'attributes' => [
        'client_name' => 'client name',
        'client_email' => 'client email',
        'website' => 'website',
        'name' => 'name',
        'email' => 'email',
        'password' => 'password',
        'country' => 'country',
        'mobile' => 'mobile',
        'category_name' => 'category name',
        'title' => 'title',
        'details' => 'details',
        'user_id' => 'employee',
        'category_id' => 'category id',
        'file' => 'file',
        'contact_name' => 'contact name',
        'import_file' => 'import file',
        'remind_time' => 'remind time',
        'next_follow_up_date' => 'next follow up date',
        'employee_id' => 'employee id',
        'department' => 'department',
        'designation' => 'designation',
        'hourly_rate' => 'hourly rate',
        'joining_date' => 'joining date',
        'last_date' => 'last date',
        'date_of_birth' => 'date of birth',
        'probation_end_date' => 'probation end date',
        'notice_period_start_date' => 'notice period start date',
        'notice_period_end_date' => 'notice period end date',
        'internship_end_date' => 'internship end date',
        'contract_end_date' => 'contract end date',
        'relationship' => 'relationship',
        'award' => 'award',
        'given_to' => 'given to',
        'award_date' => 'award date',
        'multi_date' => 'multi date',
        'year' => 'year',
        'month' => 'month',
        'office_start_time' => 'office start time',
        'office_end_time' => 'office end time',
        'shift_short_code' => 'shift short code',
        'color' => 'color',
        'late_mark_duration' => 'late mark duration',
        'clockin_in_day' => 'clock in a day',
        'office_open_days' => 'office open days',
        'clock_in_time' => 'clock in time',
        'clock_out_time' => 'clock out time',
        'working_from' => 'working from',
        'clock_in_ip' => 'clock in ip',
        'clock_out_ip' => 'clock out ip',
        'designation_name' => 'designation name',
        'team_name' => 'team name',
        'client_id' => 'client id',
        'subject' => 'subject',
        'amount' => 'amount',
        'contract_type' => 'contract type',
        'start_date' => 'start date',
        'first_name' => 'first name',
        'last_name' => 'last name',
        'signature' => 'signature',
        'image' => 'image',
        'comment' => 'comment',
        'project_name' => 'project name',
        'hours_allocated' => 'hours allocated',
        'deadline' => 'deadline',
        'project_budget' => 'project budget',
        'currency_id' => 'currency id',
        'project_id' => 'project id',
        'milestone_title' => 'milestone title',
        'summary' => 'summary',
        'discussion_category' => 'discussion category',
        'description' => 'description',
        'priority' => 'priority',
        'due_date' => 'due date',
        'repeat_cycles' => 'repeat cycles',
        'dependent_task_id' => 'dependent task id',
        'estimate_hours' => 'estimate hours',
        'estimate_minutes' => 'estimate minutes',
        'note' => 'note',
        'memo' => 'memo',
        'start_time' => 'start time',
        'end_time' => 'end time',
        'valid_till' => 'valid till',
        'sub_total' => 'sub total',
        'total' => 'total',
        'lead_id' => 'lead id',
        'estimate_number' => 'estimate number',
        'invoice_number' => 'invoice number',
        'issue_date' => 'issue date',
        'shipping_address' => 'shipping address',
        'day_of_week' => 'day of the week',
        'day_of_month' => 'day of the month',
        'cn_number' => 'cn number',
        'invoice_id' => 'invoice id',
        'item_name' => 'item name',
        'purchase_date' => 'purchase date',
        'price' => 'price',
        'billing_cycle' => 'billing cycle',
        'paid_on' => 'paid on',
        'transaction_id' => 'transaction id',
        'downloadable_file' => 'downloadable file',
        'tax_name' => 'tax name',
        'rate_percent' => 'rate percent',
        'status' => 'status',
        'order_date' => 'order date',
        'ticket_subject' => 'ticket subject',
        'ticket_description' => 'ticket description',
        'message' => 'message',
        'type' => 'type',
        'channel_name' => 'channel name',
        'event_name' => 'event name',
        'all_employees' => 'all employees',
        'where' => 'where',
        'event_link' => 'event link',
        'heading' => 'heading',
        'category' => 'category',
        'company_name' => 'company name',
        'company_email' => 'company email',
        'company_phone' => 'company phone',
        'location' => 'location',
        'address' => 'address',
        'allowed_file_types' => 'allowed file types',
        'allowed_file_size' => 'allowed file size',
        'currency_name' => 'currency name',
        'currency_symbol' => 'currency symbol',
        'usd_price' => 'usd_price',
        'exchange_rate' => 'exchange rate',
        'currency_code' => 'currency code',
        'invoice_prefix' => 'invoice prefix',
        'estimate_prefix' => 'estimate prefix',
        'credit_note_prefix' => 'credit note prefix',
        'template' => 'template',
        'due_after' => 'date after',
        'invoice_terms' => 'invoice terms',
        'app_name' => 'app name',
        'code' => 'code',
        'search_keyword' => 'search keyword',
        'reply_heading' => 'reply heading',
        'reply_text' => 'reply text',
        'send_reminder' => 'send reminder',
        'remind_to' => 'send reminder',
        'remind_type' => 'remind type',
        'radius' => 'radius',
        'alert_after' => 'alert after',
        'monthly_report_roles' => 'monthly report roles',
        'type_name' => 'type name',
        'leave_number' => 'leave number',
        'monthly_limit' => 'monthly limit',
        'label' => 'label',
        'required' => 'required',
        'agent_name' => 'agent name',
        'primary_color' => 'primary color',
        'language_name' => 'language name',
        'language_code' => 'language code',
        'flag' => 'flag',
        'additional_description' => 'additional description',
        'consent_description' => 'consent description',
        'full_name' => 'full name',
        'allow_email' => 'allow email',
        'email_domain' => 'email domain',
        'external_link' => 'external link',
        'filename' => 'filename',
        'task_id' => 'task id',
        'group_name' => 'group name',
        'column_name' => 'column name',
        'label_color' => 'label color',
        'clientName' => 'client name',
        'city' => 'city',
        'state' => 'state',
        'line1' => 'line1',
        'notetext' => 'note text',
        'value' => 'value',
        'admin_id' => 'admin id',
        'reason' => 'reason',
        'leave_date' => 'leave date',
        'duration' => 'duration',
        'leave_type_id' => 'leave type id',
        'occassion' => 'occasion',
        'date' => 'date',
        'employee_shift_id' => 'employee shift id',
        'hour_of_day' => 'hour of a day',
        'backup_after_days' => 'backup after days',
        'delete_backup_after_days' => 'delete backup after days',
        'credit_note_id' => 'credit note id',
        'billing_frequency' => 'billing frequency',
        'billing_interval' => 'billing interval',
        'work_from_type' => 'work from type',
        'label_name' => 'label name',
        'has_heading' => 'has the heading',
        'notAllowed' => 'The :attribute is not allowed',
        'effective_after' => 'Effective After',
    ],
    'selectAtLeastOne' => 'Select at least one',
    'notAllowed' => 'The :attribute is not allowed',
);
